@@ -1,14 +1,7 @@
 @BOTTOM@
-
 /* Define if you have inline */
 #undef HAVE_INLINE
 
-/* Define if you have PACKAGE */
-#undef PACKAGE
-
-/* Define if you have VERSION */
-#undef VERSION
-
 /* Define if you have the ansi CLOCKS_PER_SEC clock rate */
 #undef HAVE_CLOCKS_PER_SEC
 
@@ -31,6 +24,7 @@
 
 /* Define one of these if you have a known IEEE arithmetic interface */
 #undef HAVE_SPARCLINUX_IEEE_INTERFACE
+#undef HAVE_M68KLINUX_IEEE_INTERFACE
 #undef HAVE_LINUX_IEEE_INTERFACE
 #undef HAVE_SUNOS4_IEEE_INTERFACE
 #undef HAVE_SOLARIS_IEEE_INTERFACE
@@ -39,5 +33,10 @@
 #undef HAVE_IRIX_IEEE_INTERFACE
 #undef HAVE_AIX_IEEE_INTERFACE
 
+/* Define this if we need to include /usr/include/float.h explicitly
+   in order to get FP_RND_RN and related macros.  This is known to be
+   a problem on some Compaq Tru64 unix systems when compiled with GCC. */
+#undef FIND_FP_RND_IN_USR_INCLUDE_FLOAT_H
+
 /* Define this if printf can handle %Lf for long double */
 #undef HAVE_PRINTF_LONGDOUBLE
