@@ -1,14 +1,33 @@
+/* blas/blas.c
+ * 
+ * Copyright (C) 1996, 1997, 1998, 1999, 2000 Gerard Jungman
+ * 
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or (at
+ * your option) any later version.
+ * 
+ * This program is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
+ * 
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ */
+
 /*
  * Author:  G. Jungman
- * RCS:     $Id: blas.c,v 1.11 1999/10/19 22:02:20 jungman Exp $
+ * RCS:     $Id: blas.c,v 1.15 2000/05/04 11:25:01 bjg Exp $
  */
 /* GSL implementation of BLAS operations.
  * Conforms to gsl_blas interface.
  * Note that GSL native storage is row-major, so
  * we implement in terms of gsl_blas_raw.
  */
-#include <gsl_math.h>
-#include <gsl_errno.h>
+#include <gsl/gsl_math.h>
+#include <gsl/gsl_errno.h>
 #include "gsl_blas_types.h"
 #include "gsl_blas_raw.h"
 #include "gsl_blas.h"
@@ -27,7 +46,7 @@ int gsl_blas_sdsdot (float alpha,
 {
   CBLAS_INDEX_t N = GSL_MIN(X->size, Y->size);
   int status = GSL_SUCCESS;
-  if(X->size != Y->size) status = GSL_EINVAL;
+  if(X->size != Y->size) status = GSL_EBADLEN;
   *result = gsl_blas_raw_sdsdot(N, alpha, X->data, X->stride, Y->data, Y->stride);
   return status;
 }
@@ -39,7 +58,7 @@ int gsl_blas_dsdot (const gsl_vector_float * X,
 {
   CBLAS_INDEX_t N = GSL_MIN(X->size, Y->size);
   int status = GSL_SUCCESS;
-  if(X->size != Y->size) status = GSL_EINVAL;
+  if(X->size != Y->size) status = GSL_EBADLEN;
   *result = gsl_blas_raw_dsdot(N, X->data, X->stride, Y->data, Y->stride);
   return status;
 }
@@ -51,7 +70,7 @@ int gsl_blas_sdot (const gsl_vector_float * X,
 {
   CBLAS_INDEX_t N = GSL_MIN(X->size, Y->size);
   int status = GSL_SUCCESS;
-  if(X->size != Y->size) status = GSL_EINVAL;
+  if(X->size != Y->size) status = GSL_EBADLEN;
   *result = gsl_blas_raw_sdot(N, X->data, X->stride, Y->data, Y->stride);
   return status;
 }
@@ -63,7 +82,7 @@ int gsl_blas_ddot (const gsl_vector * X,
 {
   CBLAS_INDEX_t N = GSL_MIN(X->size, Y->size);
   int status = GSL_SUCCESS;
-  if(X->size != Y->size) status = GSL_EINVAL;
+  if(X->size != Y->size) status = GSL_EBADLEN;
   *result = gsl_blas_raw_ddot(N, X->data, X->stride, Y->data, Y->stride);
   return status;
 }
@@ -75,7 +94,7 @@ int  gsl_blas_cdotu (const gsl_vector_complex_float * X,
 {
   CBLAS_INDEX_t N = GSL_MIN(X->size, Y->size);
   int status = GSL_SUCCESS;
-  if(X->size != Y->size) status = GSL_EINVAL;
+  if(X->size != Y->size) status = GSL_EBADLEN;
   gsl_blas_raw_cdotu(N, X->data, X->stride, Y->data, Y->stride, dotu->dat);
   return status;
 }
@@ -87,7 +106,7 @@ int  gsl_blas_cdotc (const gsl_vector_complex_float * X,
 {
   CBLAS_INDEX_t N = GSL_MIN(X->size, Y->size);
   int status = GSL_SUCCESS;
-  if(X->size != Y->size) status = GSL_EINVAL;
+  if(X->size != Y->size) status = GSL_EBADLEN;
   gsl_blas_raw_cdotc(N, X->data, X->stride, Y->data, Y->stride, dotc->dat);
   return status;
 }
@@ -99,7 +118,7 @@ int  gsl_blas_zdotu (const gsl_vector_complex * X,
 {
   CBLAS_INDEX_t N = GSL_MIN(X->size, Y->size);
   int status = GSL_SUCCESS;
-  if(X->size != Y->size) status = GSL_EINVAL;
+  if(X->size != Y->size) status = GSL_EBADLEN;
   gsl_blas_raw_zdotu(N, X->data, X->stride, Y->data, Y->stride, dotu->dat);
   return status;
 }
@@ -111,7 +130,7 @@ int  gsl_blas_zdotc (const gsl_vector_complex * X,
 {
   CBLAS_INDEX_t N = GSL_MIN(X->size, Y->size);
   int status = GSL_SUCCESS;
-  if(X->size != Y->size) status = GSL_EINVAL;
+  if(X->size != Y->size) status = GSL_EBADLEN;
   gsl_blas_raw_zdotc(N, X->data, X->stride, Y->data, Y->stride, dotc->dat);
   return status;
 }
@@ -187,7 +206,7 @@ int  gsl_blas_sswap (gsl_vector_float * X,
     return GSL_SUCCESS;
   }
   else
-    return GSL_EINVAL;
+    return GSL_EBADLEN;
 }
 
 
@@ -200,7 +219,7 @@ gsl_blas_scopy (const gsl_vector_float * X,
     return GSL_SUCCESS;
   }
   else
-    return GSL_EINVAL;
+    return GSL_EBADLEN;
 }
 
 
@@ -212,7 +231,7 @@ gsl_blas_saxpy (float alpha, const gsl_vector_float * X, gsl_vector_float * Y)
     return GSL_SUCCESS;
   }
   else
-    return GSL_EINVAL;
+    return GSL_EBADLEN;
 }
 
 
@@ -224,7 +243,7 @@ gsl_blas_dswap (gsl_vector * X, gsl_vector * Y)
     return GSL_SUCCESS;
   }
   else
-    return GSL_EINVAL;
+    return GSL_EBADLEN;
 }
 
 
@@ -236,7 +255,7 @@ gsl_blas_dcopy (const gsl_vector * X, gsl_vector * Y)
     return GSL_SUCCESS;
   }
   else
-    return GSL_EINVAL;
+    return GSL_EBADLEN;
 }
 
 
@@ -248,7 +267,7 @@ gsl_blas_daxpy (double alpha, const gsl_vector * X, gsl_vector * Y)
     return GSL_SUCCESS;
   }
   else
-    return GSL_EINVAL;
+    return GSL_EBADLEN;
 }
 
 
@@ -260,7 +279,7 @@ gsl_blas_cswap (gsl_vector_complex_float * X, gsl_vector_complex_float * Y)
     return GSL_SUCCESS;
   }
   else
-    return GSL_EINVAL;
+    return GSL_EBADLEN;
 }
 
 
@@ -272,7 +291,7 @@ gsl_blas_ccopy (const gsl_vector_complex_float * X, gsl_vector_complex_float * Y
     return GSL_SUCCESS;
   }
   else
-    return GSL_EINVAL;
+    return GSL_EBADLEN;
 }
 
 
@@ -286,7 +305,7 @@ gsl_blas_caxpy (const gsl_complex_float * alpha,
     return GSL_SUCCESS;
   }
   else
-    return GSL_EINVAL;
+    return GSL_EBADLEN;
 }
 
 
@@ -298,7 +317,7 @@ gsl_blas_zswap (gsl_vector_complex * X, gsl_vector_complex * Y)
     return GSL_SUCCESS;
   }
   else
-    return GSL_EINVAL;
+    return GSL_EBADLEN;
 }
 
 
@@ -310,7 +329,7 @@ gsl_blas_zcopy (const gsl_vector_complex * X, gsl_vector_complex * Y)
     return GSL_SUCCESS;
   }
   else
-    return GSL_EINVAL;
+    return GSL_EBADLEN;
 }
 
 
@@ -322,7 +341,7 @@ gsl_blas_zaxpy (const gsl_complex * alpha, const gsl_vector_complex * X, gsl_vec
     return GSL_SUCCESS;
   }
   else
-    return GSL_EINVAL;
+    return GSL_EBADLEN;
 }
 
 
@@ -460,9 +479,11 @@ int  gsl_blas_sgemv (CBLAS_TRANSPOSE_t TransA,
 {
   size_t row_dim  = A->size1;
   size_t col_dim  = A->size2;
-  size_t tda = A->dim2 ;
-  
-  if(col_dim == X->size) {
+  size_t tda = A->tda ;
+
+  if((TransA == CblasNoTrans && col_dim == X->size && row_dim == Y->size) ||
+     (TransA == CblasTrans   && row_dim == X->size && col_dim == Y->size)
+     ) {
     gsl_blas_raw_sgemv(TransA,
                        row_dim, col_dim,
 		       alpha,
@@ -474,7 +495,7 @@ int  gsl_blas_sgemv (CBLAS_TRANSPOSE_t TransA,
     return GSL_SUCCESS;
   }
   else
-    return GSL_EINVAL;
+    return GSL_EBADLEN;
 }
 
 
@@ -487,9 +508,11 @@ int  gsl_blas_dgemv (CBLAS_TRANSPOSE_t TransA,
 {
   size_t row_dim  = A->size1;
   size_t col_dim  = A->size2;
-  size_t tda = A->dim2 ;
+  size_t tda = A->tda ;
 
-  if(col_dim == X->size) {
+  if((TransA == CblasNoTrans && col_dim == X->size && row_dim == Y->size) ||
+     (TransA == CblasTrans   && row_dim == X->size && col_dim == Y->size)
+     ) {
     gsl_blas_raw_dgemv(TransA,
                        row_dim, col_dim,
 		       alpha,
@@ -501,7 +524,7 @@ int  gsl_blas_dgemv (CBLAS_TRANSPOSE_t TransA,
     return GSL_SUCCESS;
   }
   else
-    return GSL_EINVAL;
+    return GSL_EBADLEN;
 }
 
 
@@ -514,9 +537,11 @@ int  gsl_blas_cgemv (CBLAS_TRANSPOSE_t TransA,
 {
   size_t row_dim  = A->size1;
   size_t col_dim  = A->size2;
-  size_t tda = A->dim2 ;
-  
-  if(col_dim == X->size) {
+  size_t tda = A->tda ;
+
+  if((TransA == CblasNoTrans && col_dim == X->size && row_dim == Y->size) ||
+     (TransA == CblasTrans   && row_dim == X->size && col_dim == Y->size)
+     ) {
     gsl_blas_raw_cgemv(TransA,
                        row_dim, col_dim,
 		       (float *)alpha->dat,
@@ -528,7 +553,7 @@ int  gsl_blas_cgemv (CBLAS_TRANSPOSE_t TransA,
     return GSL_SUCCESS;
   }
   else
-    return GSL_EINVAL;
+    return GSL_EBADLEN;
 }
 
 
@@ -541,9 +566,11 @@ int  gsl_blas_zgemv (CBLAS_TRANSPOSE_t TransA,
 {
   size_t row_dim  = A->size1;
   size_t col_dim  = A->size2;
-  size_t tda = A->dim2 ;
-  
-  if(col_dim == X->size) {
+  size_t tda = A->tda ;
+
+  if((TransA == CblasNoTrans && col_dim == X->size && row_dim == Y->size) ||
+     (TransA == CblasTrans   && row_dim == X->size && col_dim == Y->size)
+     ) {
     gsl_blas_raw_zgemv(TransA,
                        row_dim, col_dim,
 		       (double *)alpha->dat,
@@ -555,7 +582,7 @@ int  gsl_blas_zgemv (CBLAS_TRANSPOSE_t TransA,
     return GSL_SUCCESS;
   }
   else
-    return GSL_EINVAL;
+    return GSL_EBADLEN;
 }
 
 
@@ -571,9 +598,11 @@ int  gsl_blas_sgbmv (CBLAS_TRANSPOSE_t TransA,
 {
   size_t row_dim  = A->size1;
   size_t col_dim  = A->size2;
-  size_t tda = A->dim2 ;
-  
-  if(col_dim == X->size) {
+  size_t tda = A->tda ;
+
+  if((TransA == CblasNoTrans && col_dim == X->size && row_dim == Y->size) ||
+     (TransA == CblasTrans   && row_dim == X->size && col_dim == Y->size)
+     ) {
     gsl_blas_raw_sgbmv(TransA,
                        row_dim, col_dim, KL, KU,
 		       alpha,
@@ -585,7 +614,7 @@ int  gsl_blas_sgbmv (CBLAS_TRANSPOSE_t TransA,
     return GSL_SUCCESS;
   }
   else
-    return GSL_EINVAL;
+    return GSL_EBADLEN;
 }
 
 int  gsl_blas_dgbmv (CBLAS_TRANSPOSE_t TransA,
@@ -598,9 +627,11 @@ int  gsl_blas_dgbmv (CBLAS_TRANSPOSE_t TransA,
 {
   size_t row_dim  = A->size1;
   size_t col_dim  = A->size2;
-  size_t tda = A->dim2 ;
+  size_t tda = A->tda ;
 
-  if(col_dim == X->size) {
+  if((TransA == CblasNoTrans && col_dim == X->size && row_dim == Y->size) ||
+     (TransA == CblasTrans   && row_dim == X->size && col_dim == Y->size)
+     ) {
     gsl_blas_raw_dgbmv(TransA,
                        row_dim, col_dim, KL, KU,
 		       alpha,
@@ -612,7 +643,7 @@ int  gsl_blas_dgbmv (CBLAS_TRANSPOSE_t TransA,
     return GSL_SUCCESS;
   }
   else
-    return GSL_EINVAL;
+    return GSL_EBADLEN;
 }
 
 
@@ -626,9 +657,11 @@ int  gsl_blas_cgbmv (CBLAS_TRANSPOSE_t TransA,
 {
   size_t row_dim  = A->size1;
   size_t col_dim  = A->size2;
-  size_t tda = A->dim2 ;
+  size_t tda = A->tda ;
 
-  if(col_dim == X->size) {
+  if((TransA == CblasNoTrans && col_dim == X->size && row_dim == Y->size) ||
+     (TransA == CblasTrans   && row_dim == X->size && col_dim == Y->size)
+     ) {
     gsl_blas_raw_cgbmv(TransA,
                        row_dim, col_dim, KL, KU,
 		       (float *)alpha->dat,
@@ -640,7 +673,7 @@ int  gsl_blas_cgbmv (CBLAS_TRANSPOSE_t TransA,
     return GSL_SUCCESS;
   }
   else
-    return GSL_EINVAL;
+    return GSL_EBADLEN;
 }
 
 
@@ -654,9 +687,11 @@ int  gsl_blas_zgbmv (CBLAS_TRANSPOSE_t TransA,
 {
   size_t row_dim  = A->size1;
   size_t col_dim  = A->size2;
-  size_t tda = A->dim2 ;
-  
-  if(col_dim == X->size) {
+  size_t tda = A->tda ;
+
+  if((TransA == CblasNoTrans && col_dim == X->size && row_dim == Y->size) ||
+     (TransA == CblasTrans   && row_dim == X->size && col_dim == Y->size)
+     ) {
     gsl_blas_raw_zgbmv(TransA,
                        row_dim, col_dim, KL, KU,
 		       (double *)alpha->dat,
@@ -668,7 +703,7 @@ int  gsl_blas_zgbmv (CBLAS_TRANSPOSE_t TransA,
     return GSL_SUCCESS;
   }
   else
-    return GSL_EINVAL;
+    return GSL_EBADLEN;
 }
 
 
@@ -681,11 +716,15 @@ int  gsl_blas_strmv (CBLAS_UPLO_t Uplo,
 {
   size_t row_dim  = A->size1;
   size_t col_dim  = A->size2;
-  size_t tda = A->dim2 ;
+  size_t tda = A->tda ;
 
-  if(row_dim != col_dim) return GSL_EINVAL;
-
-  if(col_dim == X->size) {
+  if(row_dim != col_dim) {
+    return GSL_ENOTSQR;
+  }
+  else if(col_dim != X->size) {
+    return GSL_EBADLEN;
+  }
+  else {
     gsl_blas_raw_strmv(Uplo, TransA, Diag,
                        row_dim,
 		       A->data, tda,
@@ -693,8 +732,6 @@ int  gsl_blas_strmv (CBLAS_UPLO_t Uplo,
 		       );
     return GSL_SUCCESS;
   }
-  else
-    return GSL_EINVAL;
 }
 
 
@@ -705,11 +742,15 @@ int  gsl_blas_dtrmv (CBLAS_UPLO_t Uplo,
 {
   size_t row_dim  = A->size1;
   size_t col_dim  = A->size2;
-  size_t tda = A->dim2 ;
+  size_t tda = A->tda ;
 
-  if(row_dim != col_dim) return GSL_EINVAL;
-
-  if(col_dim == X->size) {
+  if(row_dim != col_dim) {
+    return GSL_ENOTSQR;
+  }
+  else if(col_dim != X->size) {
+    return GSL_EBADLEN;
+  }
+  else {
     gsl_blas_raw_dtrmv(Uplo, TransA, Diag,
                        row_dim,
 		       A->data, tda,
@@ -717,8 +758,6 @@ int  gsl_blas_dtrmv (CBLAS_UPLO_t Uplo,
 		       );
     return GSL_SUCCESS;
   }
-  else
-    return GSL_EINVAL;
 }
 
 
@@ -729,11 +768,15 @@ int  gsl_blas_ctrmv (CBLAS_UPLO_t Uplo,
 {
   size_t row_dim  = A->size1;
   size_t col_dim  = A->size2;
-  size_t tda = A->dim2 ;
+  size_t tda = A->tda ;
 
-  if(row_dim != col_dim) return GSL_EINVAL;
-
-  if(col_dim == X->size) {
+  if(row_dim != col_dim) {
+    return GSL_ENOTSQR;
+  }
+  else if(col_dim != X->size) {
+    return GSL_EBADLEN;
+  }
+  else {
     gsl_blas_raw_ctrmv(Uplo, TransA, Diag,
                        row_dim,
 		       A->data, tda,
@@ -741,8 +784,6 @@ int  gsl_blas_ctrmv (CBLAS_UPLO_t Uplo,
 		       );
     return GSL_SUCCESS;
   }
-  else
-    return GSL_EINVAL;
 }
 
 
@@ -753,11 +794,15 @@ int  gsl_blas_ztrmv (CBLAS_UPLO_t Uplo,
 {
   size_t row_dim  = A->size1;
   size_t col_dim  = A->size2;
-  size_t tda = A->dim2 ;
+  size_t tda = A->tda ;
 
-  if(row_dim != col_dim) return GSL_EINVAL;
-
-  if(col_dim == X->size) {
+  if(row_dim != col_dim) {
+    return GSL_ENOTSQR;
+  }
+  else if(col_dim != X->size) {
+    return GSL_EBADLEN;
+  }
+  else {
     gsl_blas_raw_ztrmv(Uplo, TransA, Diag,
                        row_dim,
 		       A->data, tda,
@@ -765,8 +810,6 @@ int  gsl_blas_ztrmv (CBLAS_UPLO_t Uplo,
 		       );
     return GSL_SUCCESS;
   }
-  else
-    return GSL_EINVAL;
 }
 
 
@@ -780,11 +823,15 @@ int  gsl_blas_stbmv (CBLAS_UPLO_t Uplo,
 {
   size_t row_dim  = A->size1;
   size_t col_dim  = A->size2;
-  size_t tda = A->dim2 ;
+  size_t tda = A->tda ;
 
-  if(row_dim != col_dim) return GSL_EINVAL;
-
-  if(col_dim == X->size) {
+  if(row_dim != col_dim) {
+    return GSL_ENOTSQR;
+  }
+  else if(col_dim != X->size) {
+    return GSL_EBADLEN;
+  }
+  else {
     gsl_blas_raw_stbmv(Uplo, TransA, Diag,
                        row_dim,
 		       K,
@@ -793,8 +840,6 @@ int  gsl_blas_stbmv (CBLAS_UPLO_t Uplo,
 		       );
     return GSL_SUCCESS;
   }
-  else
-    return GSL_EINVAL;
 }
 
 
@@ -806,11 +851,15 @@ int  gsl_blas_dtbmv (CBLAS_UPLO_t Uplo,
 {
   size_t row_dim  = A->size1;
   size_t col_dim  = A->size2;
-  size_t tda = A->dim2 ;
+  size_t tda = A->tda ;
 
-  if(row_dim != col_dim) return GSL_EINVAL;
-
-  if(col_dim == X->size) {
+  if(row_dim != col_dim) {
+    return GSL_ENOTSQR;
+  }
+  else if(col_dim != X->size) {
+    return GSL_EBADLEN;
+  }
+  else {
     gsl_blas_raw_dtbmv(Uplo, TransA, Diag,
                        row_dim,
 		       K,
@@ -819,8 +868,6 @@ int  gsl_blas_dtbmv (CBLAS_UPLO_t Uplo,
 		       );
     return GSL_SUCCESS;
   }
-  else
-    return GSL_EINVAL;
 }
 
 
@@ -832,11 +879,15 @@ int  gsl_blas_ctbmv (CBLAS_UPLO_t Uplo,
 {
   size_t row_dim  = A->size1;
   size_t col_dim  = A->size2;
-  size_t tda = A->dim2 ;
+  size_t tda = A->tda ;
 
-  if(row_dim != col_dim) return GSL_EINVAL;
-
-  if(col_dim == X->size) {
+  if(row_dim != col_dim) {
+    return GSL_ENOTSQR;
+  }
+  else if(col_dim != X->size) {
+    return GSL_EBADLEN;
+  }
+  else {
     gsl_blas_raw_ctbmv(Uplo, TransA, Diag,
                        row_dim,
 		       K,
@@ -845,8 +896,6 @@ int  gsl_blas_ctbmv (CBLAS_UPLO_t Uplo,
 		       );
     return GSL_SUCCESS;
   }
-  else
-    return GSL_EINVAL;
 }
 
 
@@ -858,11 +907,15 @@ int  gsl_blas_ztbmv (CBLAS_UPLO_t Uplo,
 {
   size_t row_dim  = A->size1;
   size_t col_dim  = A->size2;
-  size_t tda = A->dim2 ;
+  size_t tda = A->tda ;
 
-  if(row_dim != col_dim) return GSL_EINVAL;
-
-  if(col_dim == X->size) {
+  if(row_dim != col_dim) {
+    return GSL_ENOTSQR;
+  }
+  else if(col_dim != X->size) {
+    return GSL_EBADLEN;
+  }
+  else {
     gsl_blas_raw_ztbmv(Uplo, TransA, Diag,
                        row_dim,
 		       K,
@@ -871,8 +924,6 @@ int  gsl_blas_ztbmv (CBLAS_UPLO_t Uplo,
 		       );
     return GSL_SUCCESS;
   }
-  else
-    return GSL_EINVAL;
 }
 
 
@@ -927,11 +978,15 @@ int  gsl_blas_strsv (CBLAS_UPLO_t Uplo,
 {
   size_t row_dim  = A->size1;
   size_t col_dim  = A->size2;
-  size_t tda = A->dim2 ;
+  size_t tda = A->tda ;
 
-  if(row_dim != col_dim) return GSL_EINVAL;
-
-  if(col_dim == X->size) {
+  if(row_dim != col_dim) {
+    return GSL_ENOTSQR;
+  }
+  else if(col_dim != X->size) {
+    return GSL_EBADLEN;
+  }
+  else {
     gsl_blas_raw_strsv(Uplo, TransA, Diag,
                        row_dim,
 		       A->data, tda,
@@ -939,8 +994,6 @@ int  gsl_blas_strsv (CBLAS_UPLO_t Uplo,
 		       );
     return GSL_SUCCESS;
   }
-  else
-    return GSL_EINVAL; 
 }
 
 
@@ -951,11 +1004,15 @@ int  gsl_blas_dtrsv (CBLAS_UPLO_t Uplo,
 {
   size_t row_dim  = A->size1;
   size_t col_dim  = A->size2;
-  size_t tda = A->dim2 ;
+  size_t tda = A->tda ;
 
-  if(row_dim != col_dim) return GSL_EINVAL;
-
-  if(col_dim == X->size) {
+  if(row_dim != col_dim) {
+    return GSL_ENOTSQR;
+  }
+  else if(col_dim != X->size) {
+    return GSL_EBADLEN;
+  }
+  else {
     gsl_blas_raw_dtrsv(Uplo, TransA, Diag,
                        row_dim,
 		       A->data, tda,
@@ -963,8 +1020,6 @@ int  gsl_blas_dtrsv (CBLAS_UPLO_t Uplo,
 		       );
     return GSL_SUCCESS;
   }
-  else
-    return GSL_EINVAL; 
 }
 
 
@@ -975,11 +1030,15 @@ int  gsl_blas_ctrsv (CBLAS_UPLO_t Uplo,
 {
   size_t row_dim  = A->size1;
   size_t col_dim  = A->size2;
-  size_t tda = A->dim2 ;
+  size_t tda = A->tda ;
 
-  if(row_dim != col_dim) return GSL_EINVAL;
-
-  if(col_dim == X->size) {
+  if(row_dim != col_dim) {
+    return GSL_ENOTSQR;
+  }
+  else if(col_dim != X->size) {
+    return GSL_EBADLEN;
+  }
+  else {
     gsl_blas_raw_ctrsv(Uplo, TransA, Diag,
                        row_dim,
 		       A->data, tda,
@@ -987,8 +1046,6 @@ int  gsl_blas_ctrsv (CBLAS_UPLO_t Uplo,
 		       );
     return GSL_SUCCESS;
   }
-  else
-    return GSL_EINVAL; 
 }
 
 
@@ -999,11 +1056,15 @@ int  gsl_blas_ztrsv (CBLAS_UPLO_t Uplo,
 {
   size_t row_dim  = A->size1;
   size_t col_dim  = A->size2;
-  size_t tda = A->dim2 ;
+  size_t tda = A->tda ;
 
-  if(row_dim != col_dim) return GSL_EINVAL;
-
-  if(col_dim == X->size) {
+  if(row_dim != col_dim) {
+    return GSL_ENOTSQR;
+  }
+  else if(col_dim != X->size) {
+    return GSL_EBADLEN;
+  }
+  else {
     gsl_blas_raw_ztrsv(Uplo, TransA, Diag,
                        row_dim,
 		       A->data, tda,
@@ -1011,8 +1072,6 @@ int  gsl_blas_ztrsv (CBLAS_UPLO_t Uplo,
 		       );
     return GSL_SUCCESS;
   }
-  else
-    return GSL_EINVAL; 
 }
 
 
@@ -1026,11 +1085,15 @@ int  gsl_blas_stbsv (CBLAS_UPLO_t Uplo,
 {
   size_t row_dim  = A->size1;
   size_t col_dim  = A->size2;
-  size_t tda = A->dim2 ;
+  size_t tda = A->tda ;
 
-  if(row_dim != col_dim) return GSL_EINVAL;
-
-  if(col_dim == X->size) {
+  if(row_dim != col_dim) {
+    return GSL_ENOTSQR;
+  }
+  else if(col_dim != X->size) {
+    return GSL_EBADLEN;
+  }
+  else {
     gsl_blas_raw_stbsv(Uplo, TransA, Diag,
                        row_dim,
 		       K,
@@ -1039,8 +1102,6 @@ int  gsl_blas_stbsv (CBLAS_UPLO_t Uplo,
 		       );
     return GSL_SUCCESS;
   }
-  else
-    return GSL_EINVAL;
 }
 
 
@@ -1052,11 +1113,15 @@ int  gsl_blas_dtbsv (CBLAS_UPLO_t Uplo,
 {
   size_t row_dim  = A->size1;
   size_t col_dim  = A->size2;
-  size_t tda = A->dim2 ;
+  size_t tda = A->tda ;
 
-  if(row_dim != col_dim) return GSL_EINVAL;
-
-  if(col_dim == X->size) {
+  if(row_dim != col_dim) {
+    return GSL_ENOTSQR;
+  }
+  else if(col_dim != X->size) {
+    return GSL_EBADLEN;
+  }
+  else {
     gsl_blas_raw_dtbsv(Uplo, TransA, Diag,
                        row_dim,
 		       K,
@@ -1065,8 +1130,6 @@ int  gsl_blas_dtbsv (CBLAS_UPLO_t Uplo,
 		       );
     return GSL_SUCCESS;
   }
-  else
-    return GSL_EINVAL;
 }
 
 
@@ -1078,11 +1141,15 @@ int  gsl_blas_ctbsv (CBLAS_UPLO_t Uplo,
 {
   size_t row_dim  = A->size1;
   size_t col_dim  = A->size2;
-  size_t tda = A->dim2 ;
+  size_t tda = A->tda ;
 
-  if(row_dim != col_dim) return GSL_EINVAL;
-
-  if(col_dim == X->size) {
+  if(row_dim != col_dim) {
+    return GSL_ENOTSQR;
+  }
+  else if(col_dim != X->size) {
+    return GSL_EBADLEN;
+  }
+  else {
     gsl_blas_raw_ctbsv(Uplo, TransA, Diag,
                        row_dim,
 		       K,
@@ -1091,8 +1158,6 @@ int  gsl_blas_ctbsv (CBLAS_UPLO_t Uplo,
 		       );
     return GSL_SUCCESS;
   }
-  else
-    return GSL_EINVAL;
 }
 
 
@@ -1104,11 +1169,15 @@ int  gsl_blas_ztbsv (CBLAS_UPLO_t Uplo,
 {
   size_t row_dim  = A->size1;
   size_t col_dim  = A->size2;
-  size_t tda = A->dim2 ;
+  size_t tda = A->tda ;
 
-  if(row_dim != col_dim) return GSL_EINVAL;
-
-  if(col_dim == X->size) {
+  if(row_dim != col_dim) {
+    return GSL_ENOTSQR;
+  }
+  else if(col_dim != X->size) {
+    return GSL_EBADLEN;
+  }
+  else {
     gsl_blas_raw_ztbsv(Uplo, TransA, Diag,
                        row_dim,
 		       K,
@@ -1117,8 +1186,6 @@ int  gsl_blas_ztbsv (CBLAS_UPLO_t Uplo,
 		       );
     return GSL_SUCCESS;
   }
-  else
-    return GSL_EINVAL;
 }
 
 
@@ -1175,11 +1242,15 @@ int  gsl_blas_ssymv (CBLAS_UPLO_t Uplo,
 {
   size_t row_dim  = A->size1;
   size_t col_dim  = A->size2;
-  size_t tda = A->dim2 ;
+  size_t tda = A->tda ;
 
-  if(row_dim != col_dim) return GSL_EINVAL;
-
-  if(col_dim == X->size) {
+  if(row_dim != col_dim) {
+    return GSL_ENOTSQR;
+  }
+  else if(col_dim != X->size) {
+    return GSL_EBADLEN;
+  }
+  else {
     gsl_blas_raw_ssymv(Uplo,
                        col_dim,
 		       alpha,
@@ -1190,8 +1261,6 @@ int  gsl_blas_ssymv (CBLAS_UPLO_t Uplo,
 		       );
     return GSL_SUCCESS;
   }
-  else
-    return GSL_EINVAL;
 }
 
 
@@ -1204,11 +1273,15 @@ int  gsl_blas_dsymv (CBLAS_UPLO_t Uplo,
 {
   size_t row_dim  = A->size1;
   size_t col_dim  = A->size2;
-  size_t tda = A->dim2 ;
+  size_t tda = A->tda ;
 
-  if(row_dim != col_dim) return GSL_EINVAL;
-
-  if(col_dim == X->size) {
+  if(row_dim != col_dim) {
+    return GSL_ENOTSQR;
+  }
+  else if(col_dim != X->size) {
+    return GSL_EBADLEN;
+  }
+  else {
     gsl_blas_raw_dsymv(Uplo,
                        col_dim,
 		       alpha,
@@ -1219,8 +1292,6 @@ int  gsl_blas_dsymv (CBLAS_UPLO_t Uplo,
 		       );
     return GSL_SUCCESS;
   }
-  else
-    return GSL_EINVAL;
 }
 
 
@@ -1236,11 +1307,15 @@ int  gsl_blas_ssbmv (CBLAS_UPLO_t Uplo,
 {
   size_t row_dim  = A->size1;
   size_t col_dim  = A->size2;
-  size_t tda = A->dim2 ;
+  size_t tda = A->tda ;
 
-  if(row_dim != col_dim) return GSL_EINVAL;
-
-  if(col_dim == X->size) {
+  if(row_dim != col_dim) {
+    return GSL_ENOTSQR;
+  }
+  else if(col_dim != X->size) {
+    return GSL_EBADLEN;
+  }
+  else {
     gsl_blas_raw_ssbmv(Uplo,
                        col_dim,
 		       K,
@@ -1252,8 +1327,6 @@ int  gsl_blas_ssbmv (CBLAS_UPLO_t Uplo,
 		       );
     return GSL_SUCCESS;
   }
-  else
-    return GSL_EINVAL;
 }
 
 
@@ -1267,11 +1340,15 @@ int  gsl_blas_dsbmv (CBLAS_UPLO_t Uplo,
 {
   size_t row_dim  = A->size1;
   size_t col_dim  = A->size2;
-  size_t tda = A->dim2 ;
+  size_t tda = A->tda ;
 
-  if(row_dim != col_dim) return GSL_EINVAL;
-
-  if(col_dim == X->size) {
+  if(row_dim != col_dim) {
+    return GSL_ENOTSQR;
+  }
+  else if(col_dim != X->size) {
+    return GSL_EBADLEN;
+  }
+  else {
     gsl_blas_raw_dsbmv(Uplo,
                        col_dim,
 		       K,
@@ -1283,8 +1360,6 @@ int  gsl_blas_dsbmv (CBLAS_UPLO_t Uplo,
 		       );
     return GSL_SUCCESS;
   }
-  else
-    return GSL_EINVAL;
 }
 
 
@@ -1323,11 +1398,10 @@ int  gsl_blas_sger (float alpha,
 {
   size_t  row_dim = A->size1;
   size_t  col_dim = A->size2;
-  size_t tda = A->dim2 ;
+  size_t tda = A->tda ;
 
   /* FIXME: check this */
-  if(X->size != row_dim) return GSL_EINVAL;
-  if(Y->size != col_dim) return GSL_EINVAL;
+  if(X->size != row_dim || Y->size != col_dim) return GSL_EBADLEN;
 
   gsl_blas_raw_sger(row_dim, col_dim,
 		    alpha,
@@ -1346,11 +1420,10 @@ int  gsl_blas_dger (double alpha,
 {
   size_t  row_dim = A->size1;
   size_t  col_dim = A->size2;
-  size_t tda = A->dim2 ;
+  size_t tda = A->tda ;
 
   /* FIXME: check this */
-  if(X->size != row_dim) return GSL_EINVAL;
-  if(Y->size != col_dim) return GSL_EINVAL;
+  if(X->size != row_dim || Y->size != col_dim) return GSL_EBADLEN;
 
   gsl_blas_raw_dger(row_dim, col_dim,
 		    alpha,
@@ -1371,18 +1444,23 @@ int  gsl_blas_ssyr (CBLAS_UPLO_t Uplo,
 {
   size_t  row_dim = A->size1;
   size_t  col_dim = A->size2;
-  size_t tda = A->dim2 ;
+  size_t tda = A->tda ;
 
-  if(row_dim != col_dim) return GSL_EINVAL;
-  if(X->size != row_dim) return GSL_EINVAL;
-
-  gsl_blas_raw_ssyr(Uplo,
-                    row_dim,
-		    alpha,
-        	    X->data, X->stride,
-        	    A->data, tda
-        	    );
-  return GSL_SUCCESS;
+  if(row_dim != col_dim) {
+    return GSL_ENOTSQR;
+  }
+  else if(X->size != row_dim) {
+    return GSL_EBADLEN;
+  }
+  else {
+    gsl_blas_raw_ssyr(Uplo,
+                      row_dim,
+	  	      alpha,
+        	      X->data, X->stride,
+        	      A->data, tda
+        	      );
+    return GSL_SUCCESS;
+  }
 }
 
 
@@ -1393,10 +1471,10 @@ int  gsl_blas_dsyr (CBLAS_UPLO_t Uplo,
 {
   size_t  row_dim = A->size1;
   size_t  col_dim = A->size2;
-  size_t tda = A->dim2 ;
+  size_t tda = A->tda ;
 
-  if(row_dim != col_dim) return GSL_EINVAL;
-  if(X->size != row_dim) return GSL_EINVAL;
+  if(row_dim != col_dim) return GSL_ENOTSQR;
+  if(X->size != row_dim) return GSL_EBADLEN;
 
   gsl_blas_raw_dsyr(Uplo,
                     row_dim,
@@ -1440,11 +1518,11 @@ int  gsl_blas_ssyr2 (CBLAS_UPLO_t Uplo,
 {
   size_t  row_dim = A->size1;
   size_t  col_dim = A->size2;
-  size_t tda = A->dim2 ;
+  size_t tda = A->tda ;
 
-  if(row_dim != col_dim) return GSL_EINVAL;
-  if(X->size != col_dim) return GSL_EINVAL;
-  if(Y->size != col_dim) return GSL_EINVAL;
+  if(row_dim != col_dim) return GSL_ENOTSQR;
+  if(X->size != col_dim) return GSL_EBADLEN;
+  if(Y->size != col_dim) return GSL_EBADLEN;
   
   gsl_blas_raw_ssyr2(Uplo,
                      col_dim,
@@ -1465,11 +1543,11 @@ int  gsl_blas_dsyr2 (CBLAS_UPLO_t Uplo,
 {
   size_t  row_dim = A->size1;
   size_t  col_dim = A->size2;
-  size_t tda = A->dim2 ;
+  size_t tda = A->tda ;
 
-  if(row_dim != col_dim) return GSL_EINVAL;
-  if(X->size != col_dim) return GSL_EINVAL;
-  if(Y->size != col_dim) return GSL_EINVAL;
+  if(row_dim != col_dim) return GSL_ENOTSQR;
+  if(X->size != col_dim) return GSL_EBADLEN;
+  if(Y->size != col_dim) return GSL_EBADLEN;
   
   gsl_blas_raw_dsyr2(Uplo,
                      col_dim,
@@ -1517,23 +1595,20 @@ int  gsl_blas_chemv (CBLAS_UPLO_t Uplo,
 {
   size_t row_dim  = A->size1;
   size_t col_dim  = A->size2;
-  size_t tda = A->dim2 ;
+  size_t tda = A->tda ;
 
-  if(row_dim != col_dim) return GSL_EINVAL;
+  if(row_dim != col_dim) return GSL_ENOTSQR;
+  if(col_dim != X->size) return GSL_EBADLEN;
 
-  if(col_dim == X->size) {
-    gsl_blas_raw_chemv(Uplo,
-                       col_dim,
-		       alpha->dat,
-		       A->data, tda,
-		       X->data, X->stride,
-		       beta->dat,
-		       Y->data, Y->stride
-		       );
-    return GSL_SUCCESS;
-  }
-  else
-    return GSL_EINVAL;
+  gsl_blas_raw_chemv(Uplo,
+ 		     col_dim,
+        	     alpha->dat,
+        	     A->data, tda,
+        	     X->data, X->stride,
+        	     beta->dat,
+        	     Y->data, Y->stride
+        	     );
+  return GSL_SUCCESS;
 }
 
 
@@ -1546,23 +1621,20 @@ int  gsl_blas_zhemv (CBLAS_UPLO_t Uplo,
 {
   size_t row_dim  = A->size1;
   size_t col_dim  = A->size2;
-  size_t tda = A->dim2 ;
+  size_t tda = A->tda ;
 
-  if(row_dim != col_dim) return GSL_EINVAL;
+  if(row_dim != col_dim) return GSL_ENOTSQR;
+  if(col_dim != X->size) return GSL_EBADLEN;
 
-  if(col_dim == X->size) {
-    gsl_blas_raw_zhemv(Uplo,
-                       col_dim,
-		       alpha->dat,
-		       A->data, tda,
-		       X->data, X->stride,
-		       beta->dat,
-		       Y->data, Y->stride
-		       );
-    return GSL_SUCCESS;
-  }
-  else
-    return GSL_EINVAL;
+  gsl_blas_raw_zhemv(Uplo,
+  		     col_dim,
+        	     alpha->dat,
+        	     A->data, tda,
+        	     X->data, X->stride,
+        	     beta->dat,
+        	     Y->data, Y->stride
+        	     );
+  return GSL_SUCCESS;
 }
 
 
@@ -1578,24 +1650,21 @@ int  gsl_blas_chbmv (CBLAS_UPLO_t Uplo,
 {
   size_t row_dim  = A->size1;
   size_t col_dim  = A->size2;
-  size_t tda = A->dim2 ;
+  size_t tda = A->tda ;
 
-  if(row_dim != col_dim) return GSL_EINVAL;
+  if(row_dim != col_dim) return GSL_ENOTSQR;
+  if(col_dim != X->size) return GSL_EBADLEN;
 
-  if(col_dim == X->size) {
-    gsl_blas_raw_chbmv(Uplo,
-                       K,
-                       col_dim,
-		       alpha->dat,
-		       A->data, tda,
-		       X->data, X->stride,
-		       beta->dat,
-		       Y->data, Y->stride
-		       );
-    return GSL_SUCCESS;
-  }
-  else
-    return GSL_EINVAL;
+  gsl_blas_raw_chbmv(Uplo,
+  		     K,
+  		     col_dim,
+        	     alpha->dat,
+        	     A->data, tda,
+        	     X->data, X->stride,
+        	     beta->dat,
+        	     Y->data, Y->stride
+        	     );
+  return GSL_SUCCESS;
 }
 
 
@@ -1609,24 +1678,21 @@ int  gsl_blas_zhbmv (CBLAS_UPLO_t Uplo,
 {
   size_t row_dim  = A->size1;
   size_t col_dim  = A->size2;
-  size_t tda = A->dim2 ;
+  size_t tda = A->tda ;
 
-  if(row_dim != col_dim) return GSL_EINVAL;
+  if(row_dim != col_dim) return GSL_ENOTSQR;
+  if(col_dim != X->size) return GSL_EBADLEN;
 
-  if(col_dim == X->size) {
-    gsl_blas_raw_zhbmv(Uplo,
-                       K,
-                       col_dim,
-		       alpha->dat,
-		       A->data, tda,
-		       X->data, X->stride,
-		       beta->dat,
-		       Y->data, Y->stride
-		       );
-    return GSL_SUCCESS;
-  }
-  else
-    return GSL_EINVAL;
+  gsl_blas_raw_zhbmv(Uplo,
+  		     K,
+  		     col_dim,
+        	     alpha->dat,
+        	     A->data, tda,
+        	     X->data, X->stride,
+        	     beta->dat,
+        	     Y->data, Y->stride
+        	     );
+  return GSL_SUCCESS;
 }
 
 
@@ -1666,7 +1732,7 @@ int  gsl_blas_cgeru (const gsl_complex_float * alpha,
   gsl_blas_raw_cgeru (A->size1, A->size2, alpha->dat,
                       X->data, X->stride,
                       Y->data, Y->stride,
-                      A->data, A->dim2);
+                      A->data, A->tda);
   return GSL_SUCCESS;
 }
 
@@ -1679,7 +1745,7 @@ int  gsl_blas_zgeru (const gsl_complex * alpha,
   gsl_blas_raw_zgeru (A->size1, A->size2, alpha->dat,
                       X->data, X->stride,
                       Y->data, Y->stride,
-                      A->data, A->dim2);
+                      A->data, A->tda);
   return GSL_SUCCESS;
 }
 
@@ -1694,7 +1760,7 @@ int  gsl_blas_cgerc (const gsl_complex_float * alpha,
   gsl_blas_raw_cgerc (A->size1, A->size2, alpha->dat,
                       X->data, X->stride,
                       Y->data, Y->stride,
-                      A->data, A->dim2);
+                      A->data, A->tda);
   return GSL_SUCCESS;
 }
 
@@ -1707,7 +1773,7 @@ int  gsl_blas_zgerc (const gsl_complex * alpha,
   gsl_blas_raw_zgerc (A->size1, A->size2, alpha->dat,
                       X->data, X->stride,
                       Y->data, Y->stride,
-                      A->data, A->dim2);
+                      A->data, A->tda);
   return GSL_SUCCESS;
 }
 
@@ -1721,10 +1787,10 @@ int  gsl_blas_cher (CBLAS_UPLO_t Uplo,
 {
   size_t row_dim = A->size1;
   size_t col_dim = A->size2;
-  size_t tda = A->dim2 ;
+  size_t tda = A->tda ;
 
-  if(row_dim != col_dim) return GSL_EINVAL;
-  if(X->size != row_dim) return GSL_EINVAL;
+  if(row_dim != col_dim) return GSL_ENOTSQR;
+  if(X->size != row_dim) return GSL_EBADLEN;
 
   gsl_blas_raw_cher(Uplo,
                     row_dim,
@@ -1743,10 +1809,10 @@ int  gsl_blas_zher (CBLAS_UPLO_t Uplo,
 {
   size_t row_dim = A->size1;
   size_t col_dim = A->size2;
-  size_t tda = A->dim2 ;
+  size_t tda = A->tda ;
 
-  if(row_dim != col_dim) return GSL_EINVAL;
-  if(X->size != row_dim) return GSL_EINVAL;
+  if(row_dim != col_dim) return GSL_ENOTSQR;
+  if(X->size != row_dim) return GSL_EBADLEN;
 
   gsl_blas_raw_zher(Uplo,
                     row_dim,
@@ -1790,11 +1856,11 @@ int  gsl_blas_cher2 (CBLAS_UPLO_t Uplo,
 {
   size_t row_dim = A->size1;
   size_t col_dim = A->size2;
-  size_t tda = A->dim2 ;
+  size_t tda = A->tda ;
 
-  if(row_dim != col_dim) return GSL_EINVAL;
-  if(X->size != col_dim) return GSL_EINVAL;
-  if(Y->size != col_dim) return GSL_EINVAL;
+  if(row_dim != col_dim) return GSL_ENOTSQR;
+  if(X->size != col_dim) return GSL_EBADLEN;
+  if(Y->size != col_dim) return GSL_EBADLEN;
   
   gsl_blas_raw_cher2(Uplo,
                      col_dim,
@@ -1815,11 +1881,11 @@ int  gsl_blas_zher2 (CBLAS_UPLO_t Uplo,
 {
   size_t row_dim = A->size1;
   size_t col_dim = A->size2;
-  size_t tda = A->dim2 ;
+  size_t tda = A->tda ;
 
-  if(row_dim != col_dim) return GSL_EINVAL;
-  if(X->size != col_dim) return GSL_EINVAL;
-  if(Y->size != col_dim) return GSL_EINVAL;
+  if(row_dim != col_dim) return GSL_ENOTSQR;
+  if(X->size != col_dim) return GSL_EBADLEN;
+  if(Y->size != col_dim) return GSL_EBADLEN;
   
   gsl_blas_raw_zher2(Uplo,
                      col_dim,
@@ -1874,18 +1940,18 @@ int  gsl_blas_sgemm (CBLAS_TRANSPOSE_t TransA,
                      float beta,
                      gsl_matrix_float * C)
 {
-  if(A->size2 != B->size1) return GSL_EINVAL;
-  if(A->size1 != C->size1) return GSL_EINVAL;
-  if(B->size2 != C->size2) return GSL_EINVAL;
+  if(A->size2 != B->size1) return GSL_EBADLEN;
+  if(A->size1 != C->size1) return GSL_EBADLEN;
+  if(B->size2 != C->size2) return GSL_EBADLEN;
   
   gsl_blas_raw_sgemm(TransA, TransB,
                      C->size1, C->size2,
 		     K,
 		     alpha,
-		     A->data, A->dim2,
-		     B->data, B->dim2,
+		     A->data, A->tda,
+		     B->data, B->tda,
 		     beta,
-		     C->data, C->dim2
+		     C->data, C->tda
 		     );
   return GSL_SUCCESS;
 }
@@ -1900,18 +1966,18 @@ int  gsl_blas_dgemm (CBLAS_TRANSPOSE_t TransA,
                      double beta,
                      gsl_matrix * C)
 {
-  if(A->size2 != B->size1) return GSL_EINVAL;
-  if(A->size1 != C->size1) return GSL_EINVAL;
-  if(B->size2 != C->size2) return GSL_EINVAL;
+  if(A->size2 != B->size1) return GSL_EBADLEN;
+  if(A->size1 != C->size1) return GSL_EBADLEN;
+  if(B->size2 != C->size2) return GSL_EBADLEN;
   
   gsl_blas_raw_dgemm(TransA, TransB,
                      C->size1, C->size2,
 		     K,
 		     alpha,
-		     A->data, A->dim2,
-		     B->data, B->dim2,
+		     A->data, A->tda,
+		     B->data, B->tda,
 		     beta,
-		     C->data, C->dim2
+		     C->data, C->tda
 		     );
   return GSL_SUCCESS;
 }
@@ -1926,18 +1992,18 @@ int  gsl_blas_cgemm (CBLAS_TRANSPOSE_t TransA,
                      const gsl_complex_float * beta,
                      gsl_matrix_complex_float * C)
 {
-  if(A->size2 != B->size1) return GSL_EINVAL;
-  if(A->size1 != C->size1) return GSL_EINVAL;
-  if(B->size2 != C->size2) return GSL_EINVAL;
+  if(A->size2 != B->size1) return GSL_EBADLEN;
+  if(A->size1 != C->size1) return GSL_EBADLEN;
+  if(B->size2 != C->size2) return GSL_EBADLEN;
   
   gsl_blas_raw_cgemm(TransA, TransB,
                      C->size1, C->size2,
 		     K,
 		     (float *)alpha->dat,
-		     A->data, A->dim2,
-		     B->data, B->dim2,
+		     A->data, A->tda,
+		     B->data, B->tda,
 		     (float *)beta->dat,
-		     C->data, C->dim2
+		     C->data, C->tda
 		     );
   return GSL_SUCCESS;
 }
@@ -1952,18 +2018,18 @@ int  gsl_blas_zgemm (CBLAS_TRANSPOSE_t TransA,
                      const gsl_complex * beta,
                      gsl_matrix_complex * C)
 {
-  if(A->size2 != B->size1) return GSL_EINVAL;
-  if(A->size1 != C->size1) return GSL_EINVAL;
-  if(B->size2 != C->size2) return GSL_EINVAL;
+  if(A->size2 != B->size1) return GSL_EBADLEN;
+  if(A->size1 != C->size1) return GSL_EBADLEN;
+  if(B->size2 != C->size2) return GSL_EBADLEN;
   
   gsl_blas_raw_zgemm(TransA, TransB,
                      C->size1, C->size2,
 		     K,
 		     (double *)alpha->dat,
-		     A->data, A->dim2,
-		     B->data, B->dim2,
+		     A->data, A->tda,
+		     B->data, B->tda,
 		     (double *)beta->dat,
-		     C->data, C->dim2
+		     C->data, C->tda
 		     );
   return GSL_SUCCESS;
 }
@@ -1978,17 +2044,17 @@ int  gsl_blas_ssymm (CBLAS_SIDE_t Side, CBLAS_UPLO_t Uplo,
                      float beta,
                      gsl_matrix_float * C)
 {
-  if(A->size2 != B->size1) return GSL_EINVAL;
-  if(A->size1 != C->size1) return GSL_EINVAL;
-  if(B->size2 != C->size2) return GSL_EINVAL;
+  if(A->size2 != B->size1) return GSL_EBADLEN;
+  if(A->size1 != C->size1) return GSL_EBADLEN;
+  if(B->size2 != C->size2) return GSL_EBADLEN;
 
   gsl_blas_raw_ssymm(Side, Uplo,
                      C->size1, C->size2,
 		     alpha,
-		     A->data, A->dim2,
-		     B->data, B->dim2,
+		     A->data, A->tda,
+		     B->data, B->tda,
 		     beta,
-		     C->data, C->dim2
+		     C->data, C->tda
 		     );
   return GSL_SUCCESS;
 }
@@ -2002,17 +2068,17 @@ int  gsl_blas_dsymm (CBLAS_SIDE_t Side,
                      double beta,
                      gsl_matrix * C)
 {
-  if(A->size2 != B->size1) return GSL_EINVAL;
-  if(A->size1 != C->size1) return GSL_EINVAL;
-  if(B->size2 != C->size2) return GSL_EINVAL;
+  if(A->size2 != B->size1) return GSL_EBADLEN;
+  if(A->size1 != C->size1) return GSL_EBADLEN;
+  if(B->size2 != C->size2) return GSL_EBADLEN;
 
   gsl_blas_raw_dsymm(Side, Uplo,
                      C->size1, C->size2,
 		     alpha,
-		     A->data, A->dim2,
-		     B->data, B->dim2,
+		     A->data, A->tda,
+		     B->data, B->tda,
 		     beta,
-		     C->data, C->dim2
+		     C->data, C->tda
 		     );
   return GSL_SUCCESS;
 }
@@ -2026,17 +2092,17 @@ int  gsl_blas_csymm (CBLAS_SIDE_t Side,
                      const gsl_complex_float * beta,
                      gsl_matrix_complex_float * C)
 {
-  if(A->size2 != B->size1) return GSL_EINVAL;
-  if(A->size1 != C->size1) return GSL_EINVAL;
-  if(B->size2 != C->size2) return GSL_EINVAL;
+  if(A->size2 != B->size1) return GSL_EBADLEN;
+  if(A->size1 != C->size1) return GSL_EBADLEN;
+  if(B->size2 != C->size2) return GSL_EBADLEN;
 
   gsl_blas_raw_csymm(Side, Uplo,
                      C->size1, C->size2,
 		     alpha->dat,
-		     A->data, A->dim2,
-		     B->data, B->dim2,
+		     A->data, A->tda,
+		     B->data, B->tda,
 		     beta->dat,
-		     C->data, C->dim2
+		     C->data, C->tda
 		     );
   return GSL_SUCCESS;
 }
@@ -2049,17 +2115,17 @@ int  gsl_blas_zsymm (CBLAS_SIDE_t Side,
                      const gsl_complex * beta,
                      gsl_matrix_complex * C)
 {
-  if(A->size2 != B->size1) return GSL_EINVAL;
-  if(A->size1 != C->size1) return GSL_EINVAL;
-  if(B->size2 != C->size2) return GSL_EINVAL;
+  if(A->size2 != B->size1) return GSL_EBADLEN;
+  if(A->size1 != C->size1) return GSL_EBADLEN;
+  if(B->size2 != C->size2) return GSL_EBADLEN;
 
   gsl_blas_raw_zsymm(Side, Uplo,
                      C->size1, C->size2,
 		     alpha->dat,
-		     A->data, A->dim2,
-		     B->data, B->dim2,
+		     A->data, A->tda,
+		     B->data, B->tda,
 		     beta->dat,
-		     C->data, C->dim2
+		     C->data, C->tda
 		     );
   return GSL_SUCCESS;
 }
