@@ -1,11 +1,30 @@
-/*
- * Author:  G. Jungman
- * RCS:     $Id: blas_raw_cblas.c,v 1.5 1999/10/19 22:02:20 jungman Exp $
+/* blas/blas_raw_cblas.c
+ * 
+ * Copyright (C) 1996, 1997, 1998, 1999, 2000 Gerard Jungman
+ * 
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or (at
+ * your option) any later version.
+ * 
+ * This program is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
+ * 
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
+
 /* Implementation of gsl_blas_raw interface which
  * defers to a CBLAS conformant interface.
+ *
+ * Author:  G. Jungman
+ * RCS:     $Id: blas_raw_cblas.c,v 1.9 2000/05/04 11:25:01 bjg Exp $
  */
-#include "gsl_blas_raw.h"
+#include "gsl_blas_raw.h"  /* we conform to this */
+#include "gsl_cblas.h"     /* we use something that conforms to this */
 
 
 /*
@@ -284,7 +303,7 @@ void gsl_blas_raw_drotmg (double d1[], double d2[], double b1[],
 void gsl_blas_raw_srot (size_t N,
                         float X[], size_t incX,
                         float Y[], size_t incY,
-                        float c, float s)
+                        const float c, const float s)
 {
   cblas_srot(N, X, incX, Y, incY, c, s);
 }
@@ -900,7 +919,7 @@ void gsl_blas_raw_dspr2 (CBLAS_UPLO_t Uplo,
                          const double Y[], size_t incY,
                          double A[])
 {
-  cblas_sspr2(CblasRowMajor, Uplo, N, alpha, X, incX, Y, incY, A);
+  cblas_dspr2(CblasRowMajor, Uplo, N, alpha, X, incX, Y, incY, A);
 }
 
 
@@ -1034,7 +1053,7 @@ void gsl_blas_raw_cher (CBLAS_UPLO_t Uplo,
                         const gsl_const_complex_packed_array_float X, size_t incX,
                         gsl_complex_packed_array_float A, int lda)
 {
-  cblas_cher(CblasRowMajor, Uplo, N, X, incX, A, lda);
+  cblas_cher(CblasRowMajor, Uplo, N, alpha, X, incX, A, lda);
 }
 
 
@@ -1044,7 +1063,7 @@ void gsl_blas_raw_zher (CBLAS_UPLO_t Uplo,
                         const gsl_const_complex_packed_array X, size_t incX,
                         gsl_complex_packed_array A, int lda)
 {
-  cblas_zher(CblasRowMajor, Uplo, N, X, incX, A, lda);
+  cblas_zher(CblasRowMajor, Uplo, N, alpha, X, incX, A, lda);
 }
 
 
