@@ -1,13 +1,32 @@
-/*
- * Author:  G. Jungman
- * RCS:     $Id: blas_raw_cblas_cm.c,v 1.2 1999/10/19 22:02:20 jungman Exp $
+/* blas/blas_raw_cblas_cm.c
+ * 
+ * Copyright (C) 1996, 1997, 1998, 1999, 2000 Gerard Jungman
+ * 
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or (at
+ * your option) any later version.
+ * 
+ * This program is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
+ * 
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
+
 /* Implementation of gsl_blas_raw_cm interface which
  * defers to a CBLAS conformant interface. This includes
  * only the level 2 and level 3 functions, since the level 1
  * functions are insensitive to the storage scheme.
+ *
+ * Author:  G. Jungman
+ * RCS:     $Id: blas_raw_cblas_cm.c,v 1.4 2000/05/04 11:25:01 bjg Exp $
  */
-#include "gsl_blas_raw_cm.h"
+#include "gsl_blas_raw_cm.h"  /* we conform to this */
+#include "gsl_cblas.h"        /* we use something that conforms to this */
 
 
 /*
@@ -557,7 +576,7 @@ void gsl_blas_raw_dspr2_cm (CBLAS_UPLO_t Uplo,
                             const double Y[], int incY,
                             double A[])
 {
-  cblas_sspr2(CblasColMajor, Uplo, N, alpha, X, incX, Y, incY, A);
+  cblas_dspr2(CblasColMajor, Uplo, N, alpha, X, incX, Y, incY, A);
 }
 
 
@@ -690,7 +709,7 @@ void gsl_blas_raw_cher_cm (CBLAS_UPLO_t Uplo,
                            const void * X, int incX,
                            void * A, int lda)
 {
-  cblas_cher(CblasColMajor, Uplo, N, X, incX, A, lda);
+  cblas_cher(CblasColMajor, Uplo, N, alpha, X, incX, A, lda);
 }
 
 
@@ -700,7 +719,7 @@ void gsl_blas_raw_zher_cm (CBLAS_UPLO_t Uplo,
                            const void * X, int incX,
                            void * A, int lda)
 {
-  cblas_zher(CblasColMajor, Uplo, N, X, incX, A, lda);
+  cblas_zher(CblasColMajor, Uplo, N, alpha, X, incX, A, lda);
 }
 
 
