@@ -1,12 +1,46 @@
+/* blas/gsl_blas.h
+ * 
+ * Copyright (C) 1996, 1997, 1998, 1999, 2000 Gerard Jungman
+ * 
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or (at
+ * your option) any later version.
+ * 
+ * This program is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
+ * 
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ */
+
 /*
  * Author:  G. Jungman
- * RCS:     $Id: gsl_blas.h,v 1.10 1999/10/19 22:02:20 jungman Exp $
+ * RCS:     $Id: gsl_blas.h,v 1.15 2000/05/04 11:25:01 bjg Exp $
  */
-#ifndef GSL_BLAS_H_
-#define GSL_BLAS_H_
+#ifndef __GSL_BLAS_H__
+#define __GSL_BLAS_H__
 
-#include <gsl_vector.h>
-#include <gsl_matrix.h>
+#include <gsl/gsl_vector.h>
+#include <gsl/gsl_matrix.h>
+
+#include <gsl/gsl_blas_types.h>
+
+
+#undef __BEGIN_DECLS
+#undef __END_DECLS
+#ifdef __cplusplus
+# define __BEGIN_DECLS extern "C" {
+# define __END_DECLS }
+#else
+# define __BEGIN_DECLS /* empty */
+# define __END_DECLS /* empty */
+#endif
+
+__BEGIN_DECLS
 
 
 /* ========================================================================
@@ -144,7 +178,6 @@ void gsl_blas_csscal (float  alpha, gsl_vector_complex_float * X);
 void gsl_blas_zdscal (double alpha, gsl_vector_complex * X);
 
 
-
 /* ===========================================================================
  * Level 2
  * ===========================================================================
@@ -805,4 +838,6 @@ int  gsl_blas_zher2k (CBLAS_UPLO_t Uplo,
                       gsl_matrix_complex * C);
 
 
-#endif /* !GSL_BLAS_H_ */
+__END_DECLS
+
+#endif /* __GSL_BLAS_H__ */
