@@ -1,10 +1,30 @@
-/*
- * Author:  G. Jungman
- * RCS:     $Id: test_blas_raw.c,v 1.12 1999/10/18 05:24:41 jungman Exp $
+/* blas/test_blas_raw.c
+ * 
+ * Copyright (C) 1996, 1997, 1998, 1999, 2000 Gerard Jungman
+ * 
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or (at
+ * your option) any later version.
+ * 
+ * This program is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
+ * 
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#include <gsl_test.h>
-#include <gsl_math.h>
+/*
+ * Author:  G. Jungman
+ * RCS:     $Id: test_blas_raw.c,v 1.16 2000/05/15 19:39:13 bjg Exp $
+ */
+
+#include <gsl/gsl_test.h>
+#include <gsl/gsl_ieee_utils.h>
+#include <gsl/gsl_math.h>
 #include "test_cases.h"
 #include "gsl_blas_raw.h"
 
@@ -157,6 +177,16 @@ int test_L1(void)
   gsl_test(s, "gsl_blas_raw_snrm2 B");
   status += s;
 
+  x_f = gsl_blas_raw_snrm2(4, vector_4_zero_f, 1);
+  s = (x_f != 0);
+  gsl_test(s, "gsl_blas_raw_snrm2 A zero");
+  status += s;
+
+  x_f = gsl_blas_raw_snrm2(2, vector_4_zero_f, 3);
+  s = (x_f != 0);
+  gsl_test(s, "gsl_blas_raw_snrm2 B zero");
+  status += s;
+
 
   /* dnrm2 */
 
@@ -170,6 +200,17 @@ int test_L1(void)
   gsl_test(s, "gsl_blas_raw_dnrm2 B");
   status += s;
 
+  x_f = gsl_blas_raw_dnrm2(4, vector_4_zero_d, 1);
+  s = (x_f != 0);
+  gsl_test(s, "gsl_blas_raw_dnrm2 A zero");
+  status += s;
+
+  x_f = gsl_blas_raw_dnrm2(2, vector_4_zero_d, 3);
+  s = (x_f != 0);
+  gsl_test(s, "gsl_blas_raw_dnrm2 B zero");
+  status += s;
+
+
   /* scnrm2 */
 
   x_f = gsl_blas_raw_scnrm2(4, vector_4_c, 1);
@@ -182,6 +223,16 @@ int test_L1(void)
   gsl_test(s, "gsl_blas_raw_scnrm2 B");
   status += s;
 
+  x_f = gsl_blas_raw_scnrm2(4, vector_4_zero_c, 1);
+  s = (x_f != 0);
+  gsl_test(s, "gsl_blas_raw_scnrm2 A zero");
+  status += s;
+
+  x_f = gsl_blas_raw_scnrm2(2, vector_4_zero_c, 3);
+  s = (x_f != 0);
+  gsl_test(s, "gsl_blas_raw_scnrm2 B zero");
+  status += s;
+
 
   /* dznrm2 */
 
@@ -195,6 +246,16 @@ int test_L1(void)
   gsl_test(s, "gsl_blas_raw_zdnrm2 B");
   status += s;  
 
+  x_f = gsl_blas_raw_dznrm2(4, vector_4_zero_z, 1);
+  s = (x_f != 0);
+  gsl_test(s, "gsl_blas_raw_dznrm2 A zero");
+  status += s;
+
+  x_f = gsl_blas_raw_dznrm2(2, vector_4_zero_z, 3);
+  s = (x_f != 0);
+  gsl_test(s, "gsl_blas_raw_dznrm2 B zero");
+  status += s;
+
 
   /* sasum */
 
@@ -2503,6 +2564,8 @@ int main()
 {
   int status = 0;
 
+  gsl_ieee_env_setup ();
+
   status += test_L1();
   status += test_gemv();
   status += test_gbmv();
