@@ -1,5 +1,24 @@
+/* eigen/jacobi.c
+ * 
+ * Copyright (C) 1996, 1997, 1998, 1999, 2000 Gerard Jungman
+ * 
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or (at
+ * your option) any later version.
+ * 
+ * This program is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
+ * 
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ */
+
 /* Author:  G. Jungman
- * RCS:     $Id: jacobi.c,v 1.1 1999/10/19 11:15:05 bjg Exp $
+ * RCS:     $Id: jacobi.c,v 1.3 2000/05/04 11:25:02 bjg Exp $
  */
 /* Simple linear algebra operations, operating directly
  * on the gsl_vector and gsl_matrix objects. These are
@@ -12,9 +31,9 @@
 #include <config.h>
 #include <stdlib.h>
 #include <string.h>
-#include <gsl_math.h>
-#include <gsl_vector.h>
-#include <gsl_matrix.h>
+#include <gsl/gsl_math.h>
+#include <gsl/gsl_vector.h>
+#include <gsl/gsl_matrix.h>
 #include "gsl_eigen.h"
 
 #define REAL double
