@@ -1,8 +1,29 @@
-/* Author:  G. Jungman
- * RCS:     $Id: test.c,v 1.2 1999/11/19 20:43:01 bjg Exp $
+/* eigen/test.c
+ * 
+ * Copyright (C) 1996, 1997, 1998, 1999, 2000 Gerard Jungman
+ * 
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or (at
+ * your option) any later version.
+ * 
+ * This program is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
+ * 
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
-#include <gsl_test.h>
-#include <gsl_math.h>
+
+/* Author:  G. Jungman
+ * RCS:     $Id: test.c,v 1.8 2000/05/15 19:39:13 bjg Exp $
+ */
+#include <gsl/gsl_test.h>
+#include <gsl/gsl_math.h>
+#include <gsl/gsl_linalg.h>
+#include <gsl/gsl_ieee_utils.h>
 #include "gsl_eigen.h"
 
 gsl_matrix *
@@ -71,7 +92,7 @@ int test_invert_jacobi(void)
   gsl_matrix * hm = create_hilbert_matrix(10);
   gsl_eigen_invert_jacobi_impl(hm, hminv, 1000);
 
-  gsl_la_matmult_impl(hm, hminv, id);
+  gsl_linalg_matmult(hm, hminv, id);
 
   for(i=0; i<10; i++) {
     for(j=0; j<10; j++) {
@@ -92,6 +113,8 @@ int test_invert_jacobi(void)
 
 int main()
 {
+  gsl_ieee_env_setup ();
+
   gsl_test(test_eigen_jacobi(),   "Eigensystem:  Jacobi Method");
   gsl_test(test_invert_jacobi(),  "Inversion:    Jacobi Method");
 
