@@ -1,8 +1,27 @@
+/* histogram/pdf2d.c
+ * 
+ * Copyright (C) 1996, 1997, 1998, 1999, 2000 Brian Gough
+ * 
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or (at
+ * your option) any later version.
+ * 
+ * This program is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
+ * 
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ */
+
 #include <config.h>
 #include <stdlib.h>
-#include <gsl_errno.h>
-#include <gsl_histogram.h>
-#include <gsl_histogram2d.h>
+#include <gsl/gsl_errno.h>
+#include <gsl/gsl_histogram.h>
+#include <gsl/gsl_histogram2d.h>
 
 int
 gsl_histogram2d_pdf_sample (const gsl_histogram2d_pdf * p,
@@ -38,7 +57,7 @@ gsl_histogram2d_pdf_sample (const gsl_histogram2d_pdf * p,
       double delta = (r1 - p->sum[k]) / (p->sum[k + 1] - p->sum[k]);
       *x = p->xrange[i] + delta * (p->xrange[i + 1] - p->xrange[i]);
       *y = p->yrange[j] + r2 * (p->yrange[j + 1] - p->yrange[j]);
-      return 0;
+      return GSL_SUCCESS;
     }
 }
 
