@@ -1,7 +1,26 @@
+/* ieee-utils/fp-linux.c
+ * 
+ * Copyright (C) 1996, 1997, 1998, 1999, 2000 Brian Gough
+ * 
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or (at
+ * your option) any later version.
+ * 
+ * This program is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
+ * 
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ */
+
 #include <stdio.h>
 #include <fpu_control.h>
-#include <gsl_errno.h>
-#include <gsl_ieee_utils.h>
+#include <gsl/gsl_errno.h>
+#include <gsl/gsl_ieee_utils.h>
 
 int
 gsl_ieee_set_mode (int precision, int rounding, int exception_mask)
