@@ -1,11 +1,30 @@
+/* integration/test.c
+ * 
+ * Copyright (C) 1996, 1997, 1998, 1999, 2000 Brian Gough
+ * 
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or (at
+ * your option) any later version.
+ * 
+ * This program is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
+ * 
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ */
+
 #include <config.h>
 #include <stdio.h>
 #include <math.h>
-#include <gsl_math.h>
-#include <gsl_integration.h>
-#include <gsl_errno.h>
-#include <gsl_test.h>
-#include <gsl_ieee_utils.h>
+#include <gsl/gsl_math.h>
+#include <gsl/gsl_integration.h>
+#include <gsl/gsl_errno.h>
+#include <gsl/gsl_test.h>
+#include <gsl/gsl_ieee_utils.h>
 
 #include "tests.h"
 
@@ -1432,7 +1451,7 @@ int main (void)
 	gsl_test_rel(w->blist[i],b[i],1e-15,"qagiu(myfn1) smooth blist") ;
 
     for (i = 0; i < 5 ; i++) 
-	gsl_test_rel(w->rlist[i],r[i],1e-15,"qagiu(myfn1) smooth rlist") ;
+	gsl_test_rel(w->rlist[i],r[i],1e-14,"qagiu(myfn1) smooth rlist") ;
 
     for (i = 0; i < 5 ; i++) 
 	gsl_test_rel(w->elist[i],e[i],1e-4,"qagiu(myfn1) smooth elist") ;
@@ -1721,7 +1740,7 @@ int main (void)
 	gsl_test_rel(w->rlist[i],r[i],1e-14,"qawc(f459) rlist") ;
 
     for (i = 0; i < 6 ; i++) 
-	gsl_test_rel(w->elist[i],e[i],1e-6,"qawc(f459) elist") ;
+	gsl_test_rel(w->elist[i],e[i],1e-5,"qawc(f459) elist") ;
 
     for (i = 0; i < 6 ; i++) 
 	gsl_test_int((int)w->order[i],order[i]-1,"qawc(f459) order");
@@ -1876,6 +1895,7 @@ int main (void)
     gsl_test_rel(abserr,exp_abserr,1e-6,"qaws(f458) AB ln(x-a)ln(b-x) abserr") ;
 
     gsl_integration_workspace_free (w) ;
+    gsl_integration_qaws_table_free (t) ;
 
   }
 
@@ -2045,7 +2065,7 @@ int main (void)
     gsl_test_int(status,exp_ier,"qawf(f457) status") ;
 
     for (i = 0; i < 9 ; i++) 
-	gsl_test_rel(w->rlist[i],r[i],1e-14,"qawf(f457) rlist") ;
+	gsl_test_rel(w->rlist[i],r[i],1e-12,"qawf(f457) rlist") ;
 
     /* We can only get within two orders of magnitude on the error
        here, which is very sensitive to the floating point precision */
