@@ -1,15 +1,34 @@
+/* interpolation/test.c
+ * 
+ * Copyright (C) 1996, 1997, 1998, 1999, 2000 Gerard Jungman
+ * 
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or (at
+ * your option) any later version.
+ * 
+ * This program is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
+ * 
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ */
+
 
 /* Author:  G. Jungman
- * RCS:     $Id: test.c,v 1.3 1999/10/06 05:43:44 jungman Exp $
+ * RCS:     $Id: test.c,v 1.5 2000/05/04 11:25:04 bjg Exp $
  */
 #include <config.h>
 #include <stddef.h>
 #include <stdlib.h>
 #include <stdio.h>
 #include <math.h>
-#include <gsl_test.h>
-#include <gsl_errno.h>
-#include <gsl_interp.h>
+#include <gsl/gsl_test.h>
+#include <gsl/gsl_errno.h>
+#include <gsl/gsl_interp.h>
 
 typedef double TEST_FUNC (double);
 typedef struct _xy_table xy_table;
