@@ -1,11 +1,33 @@
+/* matrix/test.c
+ * 
+ * Copyright (C) 1996, 1997, 1998, 1999, 2000 Gerard Jungman, Brian Gough
+ * 
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or (at
+ * your option) any later version.
+ * 
+ * This program is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
+ * 
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ */
+
 #include <config.h>
 #include <stdio.h>
 #include <stdlib.h>
-#include <gsl_matrix.h>
-#include <gsl_test.h>
+#include <math.h>
+#include <gsl/gsl_math.h>
+#include <gsl/gsl_matrix.h>
+#include <gsl/gsl_test.h>
+#include <gsl/gsl_ieee_utils.h>
 
-#define N 107
 #define M 53
+#define N 107
 
 int status = 0;
 
@@ -103,6 +125,8 @@ void my_error_handler (const char *reason, const char *file,
 int
 main (void)
 {
+  gsl_ieee_env_setup ();
+
   test_func ();
   test_float_func ();
   test_long_double_func ();
