@@ -1,22 +1,41 @@
+/* monte/miser.c
+ * 
+ * Copyright (C) 1996, 1997, 1998, 1999, 2000 Michael Booth
+ * 
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or (at
+ * your option) any later version.
+ * 
+ * This program is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
+ * 
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ */
+
 /* MISER.  Based on the algorithm described in Numerical recipes. */
 
 /* Author: MJB */
-/* RCS: $Id: miser.c,v 1.17 1998/11/21 04:30:14 bjg Exp $ */
+/* RCS: $Id: miser.c,v 1.19 2000/05/04 11:25:04 bjg Exp $ */
 
 #include <config.h>
 #include <math.h>
 #include <stdlib.h>
 
 /* gsl headers */
-#include <gsl_math.h>
-/* #include <gsl_vector.h> */
-/* #include <gsl_vector_int.h> */
-#include <gsl_errno.h>
-#include <gsl_rng.h>
+#include <gsl/gsl_math.h>
+/* #include <gsl/gsl_vector.h> */
+/* #include <gsl/gsl_vector_int.h> */
+#include <gsl/gsl_errno.h>
+#include <gsl/gsl_rng.h>
 
-#include <gsl_monte.h>
-#include <gsl_monte_miser.h>
-#include <gsl_monte_plain.h>
+#include <gsl/gsl_monte.h>
+#include <gsl/gsl_monte_miser.h>
+#include <gsl/gsl_monte_plain.h>
 #include <utils.h>
 
 #define SQR(a) ((a)*(a))
