@@ -1,7 +1,26 @@
+/* monte/miser_test.c
+ * 
+ * Copyright (C) 1996, 1997, 1998, 1999, 2000 Michael Booth
+ * 
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or (at
+ * your option) any later version.
+ * 
+ * This program is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
+ * 
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ */
+
 /* Little routine to test miser integration. */
 
 /* Author: M.J. Booth */
-/* RCS: $Id: miser_test.c,v 1.12 1998/11/21 04:30:15 bjg Exp $ */
+/* RCS: $Id: miser_test.c,v 1.16 2000/05/31 20:18:55 bjg Exp $ */
 
 /* Use the examples in Lepage's paper: */
 
@@ -9,12 +28,13 @@
 #include <math.h>
 #include <stdio.h>
 
-#include <gsl_math.h>
-#include <gsl_errno.h>
-#include <gsl_test.h>
+#include <gsl/gsl_math.h>
+#include <gsl/gsl_errno.h>
+#include <gsl/gsl_test.h>
+#include <gsl/gsl_ieee_utils.h>
 
-#include <gsl_rng.h>
-#include <gsl_monte_miser.h>
+#include <gsl/gsl_rng.h>
+#include <gsl/gsl_monte_miser.h>
 
 #define SQR(x)  ((x)*(x))
 
@@ -54,7 +74,8 @@ int main()
   gsl_test_verbose(1);
   gsl_set_error_handler (&my_error_handler);
 
-  
+  gsl_ieee_env_setup ();   
+
   printf("testing allocation/innput checks\n");
 
   status = gsl_monte_miser_validate(s, xl, xu, 4, 10);
@@ -114,10 +135,12 @@ int main()
       calls = 150000;
       tol = 0.04;
     }
+    if (num_dim == 7)
+      tol = 0.06;
     if (num_dim == 8)
       tol = 0.11;
     if ( num_dim == 9) {
-      tol = 0.14;
+      tol = 0.25;
     }
     status = gsl_monte_miser_integrate(s, f1, xl, xu, num_dim, calls, 
 				       &res, &err);
