@@ -1,15 +1,34 @@
+/* monte/plain.c
+ * 
+ * Copyright (C) 1996, 1997, 1998, 1999, 2000 Michael Booth
+ * 
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or (at
+ * your option) any later version.
+ * 
+ * This program is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
+ * 
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ */
+
 /* Plain Monte-Carlo. */
 
 /* Author: MJB */
-/* RCS: $Id: plain.c,v 1.9 1998/11/21 04:30:16 bjg Exp $ */
+/* RCS: $Id: plain.c,v 1.11 2000/05/04 11:25:04 bjg Exp $ */
 
 #define TINY GSL_DBL_MIN
 
 #include <config.h>
 #include <math.h>
-#include <gsl_math.h>
-#include <gsl_monte_plain.h>
-#include <gsl_rng.h>
+#include <gsl/gsl_math.h>
+#include <gsl/gsl_monte_plain.h>
+#include <gsl/gsl_rng.h>
 #include <utils.h>
 
 int gsl_monte_plain_integrate(gsl_monte_plain_state *state, 
