@@ -1,5 +1,24 @@
+/* monte/vegas.c
+ * 
+ * Copyright (C) 1996, 1997, 1998, 1999, 2000 Michael Booth
+ * 
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or (at
+ * your option) any later version.
+ * 
+ * This program is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
+ * 
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ */
+
 /* Author: MJB */
-/* RCS $Id: vegas.c,v 1.19 1998/11/21 04:30:18 bjg Exp $ */
+/* RCS $Id: vegas.c,v 1.21 2000/05/04 11:25:05 bjg Exp $ */
 
 /* This is an implementation of the adaptive Monte-Carlo algorithm
    of G. P. Lepage, originally described in J. Comp. Phys. 27, 192(1978).
@@ -39,15 +58,15 @@
 #include <stdio.h>
 
 /* gsl headers */
-#include <gsl_math.h>
-#include <gsl_errno.h>
-#include <gsl_rng.h> 
+#include <gsl/gsl_math.h>
+#include <gsl/gsl_errno.h>
+#include <gsl/gsl_rng.h> 
 
 /* lib-specific headers */
 
 #define GSL_V_TINY 1.0e-30
 
-#include <gsl_monte_vegas.h>
+#include <gsl/gsl_monte_vegas.h>
 #include <vegas_print.h>
 
 #define myMAX(a,b) ((a) >= (b) ? (a) : (b))
