@@ -1,8 +1,27 @@
+/* multiroots/fdfsolver.c
+ * 
+ * Copyright (C) 1996, 1997, 1998, 1999, 2000 Brian Gough
+ * 
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or (at
+ * your option) any later version.
+ * 
+ * This program is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
+ * 
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ */
+
 #include <config.h>
 #include <stdlib.h>
 #include <string.h>
-#include <gsl_errno.h>
-#include <gsl_multiroots.h>
+#include <gsl/gsl_errno.h>
+#include <gsl/gsl_multiroots.h>
 
 gsl_multiroot_fdfsolver *
 gsl_multiroot_fdfsolver_alloc (const gsl_multiroot_fdfsolver_type * T, 
@@ -121,7 +140,7 @@ gsl_multiroot_fdfsolver_set (gsl_multiroot_fdfsolver * s,
                              gsl_vector * x)
 {
   s->fdf = f;
-  gsl_vector_copy(s->x,x);
+  gsl_vector_memcpy(s->x,x);
   
   return (s->type->set) (s->state, s->fdf, s->x, s->f, s->J, s->dx);
 }
