@@ -1,3 +1,22 @@
+/* multiroots/hybrid.c
+ * 
+ * Copyright (C) 1996, 1997, 1998, 1999, 2000 Brian Gough
+ * 
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or (at
+ * your option) any later version.
+ * 
+ * This program is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
+ * 
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ */
+
 #include <config.h>
 
 #include <stddef.h>
@@ -6,10 +25,10 @@
 #include <math.h>
 #include <float.h>
 
-#include <gsl_math.h>
-#include <gsl_errno.h>
-#include <gsl_multiroots.h>
-#include <gsl_linalg.h>
+#include <gsl/gsl_math.h>
+#include <gsl/gsl_errno.h>
+#include <gsl/gsl_multiroots.h>
+#include <gsl/gsl_linalg.h>
 
 #include "dogleg.c"
 
@@ -365,8 +384,8 @@ set (void *vstate, gsl_multiroot_function * func, gsl_vector * x, gsl_vector * f
 
   /* Factorize J into QR decomposition */
 
-  gsl_la_decomp_QR_impl (J, rdiag);
-  gsl_la_unpack_QR_impl (J, rdiag, q, r);
+  gsl_linalg_QR_decomp (J, rdiag);
+  gsl_linalg_QR_unpack (J, rdiag, q, r);
 
   return GSL_SUCCESS;
 }
@@ -491,8 +510,8 @@ iterate (void *vstate, gsl_multiroot_function * func, gsl_vector * x, gsl_vector
 
   if (ratio >= p0001)
     {
-      gsl_vector_copy (x, x_trial);
-      gsl_vector_copy (f, f_trial);
+      gsl_vector_memcpy (x, x_trial);
+      gsl_vector_memcpy (f, f_trial);
       state->fnorm = fnorm1;
       state->iter++;
     }
@@ -526,8 +545,8 @@ iterate (void *vstate, gsl_multiroot_function * func, gsl_vector * x, gsl_vector
 
       /* Factorize J into QR decomposition */
 
-      gsl_la_decomp_QR_impl (J, rdiag);
-      gsl_la_unpack_QR_impl (J, rdiag, q, r);
+      gsl_linalg_QR_decomp (J, rdiag);
+      gsl_linalg_QR_unpack (J, rdiag, q, r);
 
       return GSL_SUCCESS;
     }
@@ -540,7 +559,7 @@ iterate (void *vstate, gsl_multiroot_function * func, gsl_vector * x, gsl_vector
 
   /* rank-1 update of the jacobian Q'R' = Q(R + w v^T) */
 
-  gsl_la_update_QR_impl (q, r, w, v);
+  gsl_linalg_QR_update (q, r, w, v);
 
   /* No progress as measured by jacobian evaluations */
 
