@@ -1,3 +1,22 @@
+/* randist/discrete.c
+ * 
+ * Copyright (C) 1996, 1997, 1998, 1999, 2000 James Theiler, Brian Gough
+ * 
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or (at
+ * your option) any later version.
+ * 
+ * This program is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
+ * 
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ */
+
 /*
    Random Discrete Events
    
@@ -125,8 +144,8 @@
 #include <stdio.h>              /* used for NULL, also fprintf(stderr,...) */
 #include <stdlib.h>             /* used for malloc's */
 #include <math.h>
-#include <gsl_rng.h>
-#include <gsl_randist.h>
+#include <gsl/gsl_rng.h>
+#include <gsl/gsl_randist.h>
 #define DEBUG 0
 #define KNUTH_CONVENTION 1      /* Saves a few steps of arithmetic
                                  * in the call to gsl_ran_discrete()
@@ -159,7 +178,7 @@ push_stack(gsl_stack_t *s, size_t v)
 {
     if ((s->i) >= (s->N)) {
         fprintf(stderr,"Cannot push stack!\n");
-        abort();                /* fatal!! */
+        abort();                /* FIXME: fatal!! */
     }
     (s->v)[s->i] = v;
     s->i += 1;
@@ -169,7 +188,7 @@ static size_t pop_stack(gsl_stack_t *s)
 {
     if ((s->i) == 0) {
         fprintf(stderr,"Cannot pop stack!\n");
-        abort();
+        abort();               /* FIXME: fatal!! */
     }
     s->i -= 1;
     return ((s->v)[s->i]);
