@@ -1,8 +1,27 @@
+/* randist/shuffle.c
+ * 
+ * Copyright (C) 1996, 1997, 1998, 1999, 2000 James Theiler, Brian Gough
+ * 
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or (at
+ * your option) any later version.
+ * 
+ * This program is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
+ * 
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ */
+
 #include <config.h>
 #include <stdlib.h>
 #include <math.h>
-#include <gsl_rng.h>
-#include <gsl_randist.h>
+#include <gsl/gsl_rng.h>
+#include <gsl/gsl_randist.h>
 
 /* Inline swap and copy functions for moving objects around */
 
@@ -96,12 +115,6 @@ gsl_ran_sample (const gsl_rng * r, void * dest, size_t k, void * src,
 
   /* Choose k out of n items, with replacement */
 
-  if (k > n)
-    {
-      GSL_ERROR_RETURN ("k is greater than n, cannot sample more than n items",
-			GSL_EINVAL, 0) ;
-    }
-
   for (i = 0; i < k; i++)
     {
       j = n * gsl_rng_uniform (r) ;
