@@ -1,7 +1,38 @@
-#ifndef GSL_RNG_H
-#define GSL_RNG_H
+/* rng/gsl_rng.h
+ * 
+ * Copyright (C) 1996, 1997, 1998, 1999, 2000 James Theiler, Brian Gough
+ * 
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or (at
+ * your option) any later version.
+ * 
+ * This program is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
+ * 
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ */
+
+#ifndef __GSL_RNG_H__
+#define __GSL_RNG_H__
 #include <stdlib.h>
-#include <gsl_errno.h>
+#include <gsl/gsl_errno.h>
+
+#undef __BEGIN_DECLS
+#undef __END_DECLS
+#ifdef __cplusplus
+# define __BEGIN_DECLS extern "C" {
+# define __END_DECLS }
+#else
+# define __BEGIN_DECLS /* empty */
+# define __END_DECLS /* empty */
+#endif
+
+__BEGIN_DECLS
 
 typedef struct
   {
@@ -26,7 +57,6 @@ gsl_rng;
 /* These structs also need to appear in default.c so you can select
    them via the environment variable GSL_RNG_TYPE */
 
-extern const gsl_rng_type *gsl_rng_slatec;
 extern const gsl_rng_type *gsl_rng_cmrg;
 extern const gsl_rng_type *gsl_rng_gfsr4;
 extern const gsl_rng_type *gsl_rng_minstd;
@@ -39,9 +69,6 @@ extern const gsl_rng_type *gsl_rng_ran2;
 extern const gsl_rng_type *gsl_rng_ran3;
 extern const gsl_rng_type *gsl_rng_rand48;
 extern const gsl_rng_type *gsl_rng_rand;
-extern const gsl_rng_type *gsl_rng_random8_bsd;
-extern const gsl_rng_type *gsl_rng_random8_glibc2;
-extern const gsl_rng_type *gsl_rng_random8_libc5;
 extern const gsl_rng_type *gsl_rng_random128_bsd;
 extern const gsl_rng_type *gsl_rng_random128_glibc2;
 extern const gsl_rng_type *gsl_rng_random128_libc5;
@@ -54,6 +81,9 @@ extern const gsl_rng_type *gsl_rng_random32_libc5;
 extern const gsl_rng_type *gsl_rng_random64_bsd;
 extern const gsl_rng_type *gsl_rng_random64_glibc2;
 extern const gsl_rng_type *gsl_rng_random64_libc5;
+extern const gsl_rng_type *gsl_rng_random8_bsd;
+extern const gsl_rng_type *gsl_rng_random8_glibc2;
+extern const gsl_rng_type *gsl_rng_random8_libc5;
 extern const gsl_rng_type *gsl_rng_random_bsd;
 extern const gsl_rng_type *gsl_rng_random_glibc2;
 extern const gsl_rng_type *gsl_rng_random_libc5;
@@ -61,12 +91,13 @@ extern const gsl_rng_type *gsl_rng_randu;
 extern const gsl_rng_type *gsl_rng_ranf;
 extern const gsl_rng_type *gsl_rng_ranlux389;
 extern const gsl_rng_type *gsl_rng_ranlux;
+extern const gsl_rng_type *gsl_rng_ranlxd1;
+extern const gsl_rng_type *gsl_rng_ranlxd2;
 extern const gsl_rng_type *gsl_rng_ranlxs0;
 extern const gsl_rng_type *gsl_rng_ranlxs1;
 extern const gsl_rng_type *gsl_rng_ranlxs2;
-extern const gsl_rng_type *gsl_rng_ranlxd1;
-extern const gsl_rng_type *gsl_rng_ranlxd2;
 extern const gsl_rng_type *gsl_rng_ranmar;
+extern const gsl_rng_type *gsl_rng_slatec;
 extern const gsl_rng_type *gsl_rng_taus;
 extern const gsl_rng_type *gsl_rng_transputer;
 extern const gsl_rng_type *gsl_rng_tt800;
@@ -79,7 +110,7 @@ extern const gsl_rng_type *gsl_rng_default;
 extern unsigned long int gsl_rng_default_seed;
 
 gsl_rng *gsl_rng_alloc (const gsl_rng_type * T);
-gsl_rng *gsl_rng_cpy (gsl_rng * dest, const gsl_rng * src);
+int gsl_rng_memcpy (gsl_rng * dest, const gsl_rng * src);
 gsl_rng *gsl_rng_clone (const gsl_rng * r);
 
 void gsl_rng_free (gsl_rng * r);
@@ -159,4 +190,6 @@ gsl_rng_uniform_int (const gsl_rng * r, unsigned long int n)
 }
 #endif /* HAVE_INLINE */
 
-#endif /* GSL_RNG_H */
+__END_DECLS
+
+#endif /* __GSL_RNG_H__ */
