@@ -1,3 +1,22 @@
+/* roots/bisection.c
+ * 
+ * Copyright (C) 1996, 1997, 1998, 1999, 2000 Reid Priedhorsky, Brian Gough
+ * 
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or (at
+ * your option) any later version.
+ * 
+ * This program is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
+ * 
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ */
+
 
 /* bisection.c -- bisection root finding algorithm */
 
@@ -9,9 +28,9 @@
 #include <math.h>
 #include <float.h>
 
-#include <gsl_math.h>
-#include <gsl_errno.h>
-#include <gsl_roots.h>
+#include <gsl/gsl_math.h>
+#include <gsl/gsl_errno.h>
+#include <gsl/gsl_roots.h>
 
 #include "roots.h"
 
@@ -21,10 +40,10 @@ typedef struct
   }
 bisection_state_t;
 
-int bisection_init (void * vstate, gsl_function * f, double * root, gsl_interval * x);
-int bisection_iterate (void * vstate, gsl_function * f, double * root, gsl_interval * x);
+static int bisection_init (void * vstate, gsl_function * f, double * root, gsl_interval * x);
+static int bisection_iterate (void * vstate, gsl_function * f, double * root, gsl_interval * x);
 
-int
+static int
 bisection_init (void * vstate, gsl_function * f, double * root, gsl_interval * x)
 {
   bisection_state_t * state = (bisection_state_t *) vstate;
@@ -51,7 +70,7 @@ bisection_init (void * vstate, gsl_function * f, double * root, gsl_interval * x
 
 }
 
-int
+static int
 bisection_iterate (void * vstate, gsl_function * f, double * root, gsl_interval * x)
 {
   bisection_state_t * state = (bisection_state_t *) vstate;
