@@ -1,9 +1,29 @@
+/* siman/test.c
+ * 
+ * Copyright (C) 1996, 1997, 1998, 1999, 2000 Mark Galassi
+ * 
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or (at
+ * your option) any later version.
+ * 
+ * This program is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
+ * 
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ */
+
 #include <config.h>
 #include <string.h>
 #include <math.h>
-#include <gsl_test.h>
-#include <gsl_rng.h>
-#include <gsl_siman.h>
+#include <gsl/gsl_test.h>
+#include <gsl/gsl_rng.h>
+#include <gsl/gsl_siman.h>
+#include <gsl/gsl_ieee_utils.h>
 #include <stdio.h>
 
 /* set up parameters for this simulated annealing run */
@@ -213,6 +233,8 @@ int main(void)
 
   gsl_rng * r = gsl_rng_alloc (gsl_rng_env_setup()) ;
 
+  gsl_ieee_env_setup ();
+
   /* The function tested here has multiple mimima. 
      The global minimum is at    x = 1.36312999, (f = -0.87287)
      There is a local minimum at x = 0.60146196, (f = -0.84893) */
