@@ -1,9 +1,28 @@
+/* specfunc/bessel_J0.c
+ * 
+ * Copyright (C) 1996, 1997, 1998, 1999, 2000 Gerard Jungman
+ * 
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or (at
+ * your option) any later version.
+ * 
+ * This program is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
+ * 
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ */
+
 /* Author:  G. Jungman
- * RCS:     $Id: bessel_J0.c,v 1.23 1999/01/21 17:01:04 jungman Exp $
+ * RCS:     $Id: bessel_J0.c,v 1.26 2000/05/04 11:25:07 bjg Exp $
  */
 #include <config.h>
-#include <gsl_math.h>
-#include <gsl_errno.h>
+#include <gsl/gsl_math.h>
+#include <gsl/gsl_errno.h>
 #include "bessel.h"
 #include "bessel_amp_phase.h"
 #include "gsl_sf_chebyshev.h"
@@ -73,8 +92,8 @@ int gsl_sf_bessel_J0_impl(const double x, gsl_sf_result * result)
     gsl_sf_result ca;
     gsl_sf_result ct;
     gsl_sf_result cp;
-    const int stat_ca = gsl_sf_cheb_eval_impl(&_bessel_amp_phase_bm0_cs,  z, &ca);
-    const int stat_ct = gsl_sf_cheb_eval_impl(&_bessel_amp_phase_bth0_cs, z, &ct);
+    const int stat_ca = gsl_sf_cheb_eval_impl(&_gsl_sf_bessel_amp_phase_bm0_cs,  z, &ca);
+    const int stat_ct = gsl_sf_cheb_eval_impl(&_gsl_sf_bessel_amp_phase_bth0_cs, z, &ct);
     const int stat_cp = gsl_sf_bessel_cos_pi4_impl(y, ct.val/y, &cp);
     const double sqrty = sqrt(y);
     const double ampl  = (0.75 + ca.val) / sqrty;
