@@ -1,10 +1,29 @@
+/* specfunc/chebyshev.c
+ * 
+ * Copyright (C) 1996, 1997, 1998, 1999, 2000 Gerard Jungman
+ * 
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or (at
+ * your option) any later version.
+ * 
+ * This program is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
+ * 
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ */
+
 /* Author:  G. Jungman
- * RCS:     $Id: chebyshev.c,v 1.21 1999/05/07 23:36:22 jungman Exp $
+ * RCS:     $Id: chebyshev.c,v 1.24 2000/05/04 11:25:07 bjg Exp $
  */
 #include <config.h>
 #include <stdlib.h>
-#include <gsl_math.h>
-#include <gsl_errno.h>
+#include <gsl/gsl_math.h>
+#include <gsl/gsl_errno.h>
 #include "gsl_sf_chebyshev.h"
 
 
@@ -352,12 +371,15 @@ int gsl_sf_cheb_eval_integ_e(gsl_sf_cheb_series * cs, double x, gsl_sf_result *
   return status;
 }
 
+
 /*-*-*-*-*-*-*-*-*-*-*-* Functions w/ Natural Prototypes *-*-*-*-*-*-*-*-*/
 
 void gsl_sf_cheb_free(gsl_sf_cheb_series * cs)
 {
   if(cs != 0) {
     if(cs->c != 0) free(cs->c);
+    if(cs->cp != 0) free(cs->cp);
+    if(cs->ci != 0) free(cs->ci);
     free(cs);
   }
 }
