@@ -1,10 +1,29 @@
+/* specfunc/ellint.c
+ * 
+ * Copyright (C) 1996, 1997, 1998, 1999, 2000 Gerard Jungman
+ * 
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or (at
+ * your option) any later version.
+ * 
+ * This program is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
+ * 
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ */
+
 /* Author: G. Jungman
- * RCS: $Id: ellint.c,v 1.16 1999/10/12 04:07:44 jungman Exp $
+ * RCS: $Id: ellint.c,v 1.18 2000/05/04 11:25:07 bjg Exp $
  */
 #include <config.h>
-#include <gsl_math.h>
-#include <gsl_errno.h>
-#include <gsl_precision.h>
+#include <gsl/gsl_math.h>
+#include <gsl/gsl_errno.h>
+#include <gsl/gsl_precision.h>
 #include "gsl_sf_ellint.h"
 
 
