@@ -1,5 +1,24 @@
+/* specfunc/erfc.c
+ * 
+ * Copyright (C) 1996, 1997, 1998, 1999, 2000 Gerard Jungman
+ * 
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or (at
+ * your option) any later version.
+ * 
+ * This program is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
+ * 
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ */
+
 /* Author:  J. Theiler (modifications by G. Jungman)
- * RCS:     $Id: erfc.c,v 1.18 1999/08/30 10:35:59 bjg Exp $
+ * RCS:     $Id: erfc.c,v 1.20 2000/05/04 11:25:07 bjg Exp $
  */
 /*
  * See Hart et al, Computer Approximations, John Wiley and Sons, New York (1968)
@@ -9,8 +28,8 @@
  *  more precise than the original approximations. [GJ])
  */
 #include <config.h>
-#include <gsl_math.h>
-#include <gsl_errno.h>
+#include <gsl/gsl_math.h>
+#include <gsl/gsl_errno.h>
 #include "gsl_sf_chebyshev.h"
 #include "gsl_sf_erf.h"
 
