@@ -1,11 +1,42 @@
-/* Author: G. Jungman
- * RCS: $Id: gsl_sf_ellint.h,v 1.8 1998/12/15 17:25:54 jungman Exp $
+/* specfunc/gsl_sf_ellint.h
+ * 
+ * Copyright (C) 1996, 1997, 1998, 1999, 2000 Gerard Jungman
+ * 
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or (at
+ * your option) any later version.
+ * 
+ * This program is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
+ * 
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
-#ifndef GSL_ELLINT_H_
-#define GSL_ELLINT_H_
 
-#include <gsl_mode.h>
-#include <gsl_sf_result.h>
+/* Author: G. Jungman
+ * RCS: $Id: gsl_sf_ellint.h,v 1.12 2000/05/04 11:25:07 bjg Exp $
+ */
+#ifndef __GSL_SF_ELLINT_H__
+#define __GSL_SF_ELLINT_H__
+
+#include <gsl/gsl_mode.h>
+#include <gsl/gsl_sf_result.h>
+
+#undef __BEGIN_DECLS
+#undef __END_DECLS
+#ifdef __cplusplus
+# define __BEGIN_DECLS extern "C" {
+# define __END_DECLS }
+#else
+# define __BEGIN_DECLS /* empty */
+# define __END_DECLS /* empty */
+#endif
+
+__BEGIN_DECLS
 
 
 /* Legendre form of complete elliptic integrals
@@ -65,4 +96,6 @@ int gsl_sf_ellint_RJ_impl(double x, double y, double z, double p, gsl_mode_t mod
 int gsl_sf_ellint_RJ_e(double x, double y, double z, double p, gsl_mode_t mode, gsl_sf_result * result);
 
 
-#endif  /* !GSL_ELLINT_H_ */
+__END_DECLS
+
+#endif /* __GSL_SF_ELLINT_H__ */
