@@ -1,9 +1,28 @@
+/* specfunc/test_bessel.c
+ * 
+ * Copyright (C) 1996, 1997, 1998, 1999, 2000 Gerard Jungman
+ * 
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or (at
+ * your option) any later version.
+ * 
+ * This program is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
+ * 
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ */
+
 /* Author:  G. Jungman
- * RCS:     $Id: test_bessel.c,v 1.16 1999/08/01 11:29:32 jungman Exp $
+ * RCS:     $Id: test_bessel.c,v 1.19 2000/05/04 11:25:08 bjg Exp $
  */
 #include <config.h>
-#include <gsl_test.h>
-#include <gsl_sf.h>
+#include <gsl/gsl_test.h>
+#include <gsl/gsl_sf.h>
 #include "test_sf.h"
 
 
@@ -122,6 +141,8 @@ int test_bessel(void)
   TEST_SF(s,  gsl_sf_bessel_j2_impl, (100.0, &r), 0.004803441652487953480, TEST_TOL1, GSL_SUCCESS);
   TEST_SF(s,  gsl_sf_bessel_j2_impl, (1048576.0, &r), -3.1518539455252413111e-07, TEST_TOL2, GSL_SUCCESS);
 
+  TEST_SF(s,  gsl_sf_bessel_jl_impl, (0, 0.0, &r), 1.0, TEST_TOL0, GSL_SUCCESS);
+
   TEST_SF(s,  gsl_sf_bessel_jl_impl, (1,       10.0, &r),   0.07846694179875154709000, TEST_TOL0, GSL_SUCCESS);
   TEST_SF(s,  gsl_sf_bessel_jl_impl, (5,        1.0, &r),   0.00009256115861125816357, TEST_TOL0, GSL_SUCCESS);
   TEST_SF(s,  gsl_sf_bessel_jl_impl, (10,      10.0, &r),   0.06460515449256426427,    TEST_TOL0, GSL_SUCCESS);
