@@ -1,15 +1,34 @@
+/* specfunc/test_sf.c
+ * 
+ * Copyright (C) 1996, 1997, 1998, 1999, 2000 Gerard Jungman
+ * 
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or (at
+ * your option) any later version.
+ * 
+ * This program is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
+ * 
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ */
+
 /* Author:  G. Jungman
- * RCS:     $Id: test_sf.c,v 1.158 1999/08/03 00:17:38 jungman Exp $
+ * RCS:     $Id: test_sf.c,v 1.161 2000/05/04 11:25:08 bjg Exp $
  */
 #include <config.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#include <gsl_math.h>
-#include <gsl_errno.h>
-#include <gsl_ieee_utils.h>
-#include <gsl_test.h>
-#include <gsl_sf.h>
+#include <gsl/gsl_math.h>
+#include <gsl/gsl_errno.h>
+#include <gsl/gsl_ieee_utils.h>
+#include <gsl/gsl_test.h>
+#include <gsl/gsl_sf.h>
 #include "test_sf.h"
 
 
@@ -1028,7 +1047,7 @@ int test_psi(void)
   TEST_SF(s, gsl_sf_psi_impl, (5.0, &r), 1.5061176684318004727, TEST_TOL0, GSL_SUCCESS);
   TEST_SF(s, gsl_sf_psi_impl, (5000.0, &r), 8.517093188082904107, TEST_TOL0, GSL_SUCCESS);
 
-  TEST_SF(s, gsl_sf_psi_impl, (-100.5, &r),      4.615124601338064117,  TEST_TOL1, GSL_SUCCESS);
+  TEST_SF(s, gsl_sf_psi_impl, (-100.5, &r),      4.615124601338064117,  TEST_TOL2, GSL_SUCCESS);
   TEST_SF(s, gsl_sf_psi_impl, (-1.0e+5-0.5, &r), 11.512935464924395337, 4.0*TEST_TOL4, GSL_SUCCESS);
   
   TEST_SF(s, gsl_sf_psi_1piy_impl, (0.8, &r), -0.07088340212750589223, TEST_TOL1, GSL_SUCCESS);
