@@ -1,12 +1,31 @@
+/* specfunc/test_sf.h
+ * 
+ * Copyright (C) 1996, 1997, 1998, 1999, 2000 Gerard Jungman
+ * 
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or (at
+ * your option) any later version.
+ * 
+ * This program is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
+ * 
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ */
+
 /* Author:  G. Jungman
- * RCS:     $Id: test_sf.h,v 1.11 1999/08/10 20:37:38 jungman Exp $
+ * RCS:     $Id: test_sf.h,v 1.13 2000/05/04 11:25:08 bjg Exp $
  */
 #ifndef TEST_SF_H
 #define TEST_SF_H
 
-#include <gsl_math.h>
-#include <gsl_errno.h>
-#include <gsl_machine.h>
+#include <gsl/gsl_math.h>
+#include <gsl/gsl_errno.h>
+#include <gsl/gsl_machine.h>
 #include "gsl_sf_result.h"
 
 double test_sf_frac_diff(double x1, double x2);
