@@ -1,11 +1,30 @@
+/* sum/levin_u.c
+ * 
+ * Copyright (C) 1996, 1997, 1998, 1999, 2000 Gerard Jungman, Brian Gough
+ * 
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or (at
+ * your option) any later version.
+ * 
+ * This program is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
+ * 
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ */
+
 /* Author:  G. Jungman
-   RCS:     $Id: levin_u.c,v 1.8 1999/11/01 16:33:06 bjg Exp $ */
+   RCS:     $Id: levin_u.c,v 1.10 2000/05/04 11:25:09 bjg Exp $ */
 
 #include <config.h>
-#include <gsl_math.h>
-#include <gsl_test.h>
-#include <gsl_errno.h>
-#include <gsl_sum.h>
+#include <gsl/gsl_math.h>
+#include <gsl/gsl_test.h>
+#include <gsl/gsl_errno.h>
+#include <gsl/gsl_sum.h>
 
 int
 gsl_sum_levin_u_trunc_accel (const double *array,
