@@ -37,7 +37,9 @@
 #undef MULTIPLICITY
 #undef IN_FORMAT
 #undef OUT_FORMAT
+#undef ATOMIC_IO
 #undef ZERO
+#undef ONE
 #undef NAME
 #undef STRING
 #undef EXPAND
