@@ -12,7 +12,9 @@
 #define MULTIPLICITY 2
 #define IN_FORMAT "%Lg"
 #define OUT_FORMAT "%Lg"
-#define ZERO {{0,0}}
+#define ATOMIC_IO ATOMIC
+#define ZERO {{0.0L,0.0L}}
+#define ONE {{1.0L,0.0L}}
 
 #elif defined(BASE_GSL_COMPLEX)
 #define BASE gsl_complex
@@ -21,7 +23,9 @@
 #define MULTIPLICITY 2
 #define IN_FORMAT "%lg"
 #define OUT_FORMAT "%g"
+#define ATOMIC_IO ATOMIC
 #define ZERO {{0,0}}
+#define ONE {{1,0}}
 
 #elif defined(BASE_GSL_COMPLEX_FLOAT)
 #define BASE gsl_complex_float
@@ -30,7 +34,9 @@
 #define MULTIPLICITY 2
 #define IN_FORMAT "%g"
 #define OUT_FORMAT "%g"
+#define ATOMIC_IO ATOMIC
 #define ZERO {{0,0}}
+#define ONE {{1,0}}
 
 #elif defined(BASE_LONG_DOUBLE)
 #define BASE long double
@@ -40,7 +46,9 @@
 #define MULTIPLICITY 1
 #define IN_FORMAT "%Lg"
 #define OUT_FORMAT "%Lg"
-#define ZERO 0
+#define ATOMIC_IO ATOMIC
+#define ZERO 0.0L
+#define ONE 1.0L
 
 #elif defined(BASE_DOUBLE)
 #define BASE double
@@ -49,7 +57,9 @@
 #define MULTIPLICITY 1
 #define IN_FORMAT "%lg"
 #define OUT_FORMAT "%g"
+#define ATOMIC_IO ATOMIC
 #define ZERO 0
+#define ONE 1
 #define BASE_EPSILON GSL_DBL_EPSILON
 
 #elif defined(BASE_FLOAT)
@@ -59,7 +69,9 @@
 #define MULTIPLICITY 1
 #define IN_FORMAT "%g"
 #define OUT_FORMAT "%g"
+#define ATOMIC_IO ATOMIC
 #define ZERO 0
+#define ONE 1
 #define BASE_EPSILON GSL_FLT_EPSILON
 
 #elif defined(BASE_ULONG)
@@ -69,7 +81,9 @@
 #define MULTIPLICITY 1
 #define IN_FORMAT "%lu"
 #define OUT_FORMAT "%lu"
+#define ATOMIC_IO ATOMIC
 #define ZERO 0
+#define ONE 1
 
 #elif defined(BASE_LONG)
 #define BASE long
@@ -78,7 +92,9 @@
 #define MULTIPLICITY 1
 #define IN_FORMAT "%ld"
 #define OUT_FORMAT "%ld"
+#define ATOMIC_IO ATOMIC
 #define ZERO 0
+#define ONE 1
 
 #elif defined(BASE_UINT)
 #define BASE unsigned int
@@ -87,7 +103,9 @@
 #define MULTIPLICITY 1
 #define IN_FORMAT "%u"
 #define OUT_FORMAT "%u"
+#define ATOMIC_IO ATOMIC
 #define ZERO 0
+#define ONE 1
 
 #elif defined(BASE_INT)
 #define BASE int
@@ -96,7 +114,9 @@
 #define MULTIPLICITY 1
 #define IN_FORMAT "%d"
 #define OUT_FORMAT "%d"
+#define ATOMIC_IO ATOMIC
 #define ZERO 0
+#define ONE 1
 
 #elif defined(BASE_USHORT)
 #define BASE unsigned short
@@ -105,7 +125,9 @@
 #define MULTIPLICITY 1
 #define IN_FORMAT "%hu"
 #define OUT_FORMAT "%hu"
+#define ATOMIC_IO ATOMIC
 #define ZERO 0
+#define ONE 1
 
 #elif defined(BASE_SHORT)
 #define BASE short
@@ -114,25 +136,31 @@
 #define MULTIPLICITY 1
 #define IN_FORMAT "%hd"
 #define OUT_FORMAT "%hd"
+#define ATOMIC_IO ATOMIC
 #define ZERO 0
+#define ONE 1
 
 #elif defined(BASE_UCHAR)
 #define BASE unsigned char
 #define SHORT uchar
 #define ATOMIC unsigned char
 #define MULTIPLICITY 1
-#define IN_FORMAT "%c%*c"
-#define OUT_FORMAT "%c"
+#define IN_FORMAT "%u"
+#define OUT_FORMAT "%u"
+#define ATOMIC_IO unsigned int
 #define ZERO 0
+#define ONE 1
 
 #elif defined(BASE_CHAR)
 #define BASE char
 #define SHORT char
 #define ATOMIC char
 #define MULTIPLICITY 1
-#define IN_FORMAT "%c%*c"
-#define OUT_FORMAT "%c"
+#define IN_FORMAT "%d"
+#define OUT_FORMAT "%d"
+#define ATOMIC_IO int
 #define ZERO 0
+#define ONE 1
 
 #else
 #error unknown BASE_ directive in source.h
