@@ -1,3 +1,22 @@
+/* vector/test_complex_source.c
+ * 
+ * Copyright (C) 1996, 1997, 1998, 1999, 2000 Gerard Jungman, Brian Gough
+ * 
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or (at
+ * your option) any later version.
+ * 
+ * This program is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
+ * 
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ */
+
 void FUNCTION (test, func) (void);
 void FUNCTION (test, binary) (void);
 void FUNCTION (test, trap) (void);
@@ -79,6 +98,53 @@ FUNCTION (test, func) (void)
   
   gsl_test (status, NAME (gsl_vector) "_set writes into array correctly with stride");
 
+  /* Reset stride to 1 */
+
+  v->stride = 1 ;
+
+  for (i = 0; i < N; i++)
+    {
+      BASE x = ZERO;
+      GSL_REAL (x) = i;
+      GSL_IMAG (x) = i + 1234;
+      FUNCTION (gsl_vector, set) (v, i, x);
+    };
+
+
+  {
+    BASE x, y ;
+    GSL_REAL(x) = 2 ;
+    GSL_IMAG(x) = 2 + 1234;
+    GSL_REAL(y) = 5 ;
+    GSL_IMAG(y) = 5 + 1234;
+
+    FUNCTION (gsl_vector,swap_elements) (v, 2, 5) ;
+    
+    status = ! GSL_COMPLEX_EQ(FUNCTION(gsl_vector,get)(v,2),y) ;
+    status |= ! GSL_COMPLEX_EQ(FUNCTION(gsl_vector,get)(v,5),x) ;
+    
+    FUNCTION (gsl_vector,swap_elements) (v, 2, 5) ;
+    
+    status |= ! GSL_COMPLEX_EQ(FUNCTION(gsl_vector,get)(v,2),x) ;
+    status |= ! GSL_COMPLEX_EQ(FUNCTION(gsl_vector,get)(v,5),y) ;
+  }
+
+  gsl_test (status, NAME(gsl_vector) "_swap_elements" DESC " exchanges elements correctly") ;
+
+  status = 0;
+
+  FUNCTION (gsl_vector,reverse) (v) ;
+  
+  for (i = 0; i < N; i++)
+    {
+      BASE x ;
+      GSL_REAL(x) = N - i - 1 ;
+      GSL_IMAG(x) = N - i - 1 + 1234;
+
+      status |= !GSL_COMPLEX_EQ(FUNCTION (gsl_vector, get) (v, i),x);
+    }
+
+  gsl_test (status, NAME(gsl_vector) "_reverse" DESC " reverses elements correctly") ;
   
   FUNCTION (gsl_vector, free) (v);	/* free whatever is in v */
 }
