@@ -1,3 +1,22 @@
+/* vector/vector_source.c
+ * 
+ * Copyright (C) 1996, 1997, 1998, 1999, 2000 Gerard Jungman, Brian Gough
+ * 
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or (at
+ * your option) any later version.
+ * 
+ * This program is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
+ * 
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ */
+
 inline BASE
 FUNCTION (gsl_vector, get) (const TYPE (gsl_vector) * v, const size_t i)
 {
@@ -31,18 +50,3 @@ FUNCTION (gsl_vector, set) (TYPE (gsl_vector) * v, const size_t i, BASE x)
   *(BASE *) (v->data + MULTIPLICITY * i * v->stride) = x;
 }
 
-void
-FUNCTION (gsl_vector, set_all) (TYPE (gsl_vector) * v, BASE x)
-{
-  ATOMIC * const data = v->data;
-  const size_t n = v->size;
-  const size_t stride = v->stride;
-
-  size_t i;
-
-  for (i = 0; i < n; i++)
-    {
-      *(BASE *) (data + MULTIPLICITY * i * stride) = x;
-    }
-}
-
